﻿import { IRoute } from 'umi';

// umi routes: https://umijs.org/docs/routing
const routes: IRoute[] = [
  {
    path: '/admin',
    layout: false,
    routes: [
      {
        name: '谷歌验证',
        path: '/admin/verify',
        component: './user/verify',
        menu: false,
      },
      {
        path: '/admin/login',
        layout: false,
        name: '登录',
        component: './user/Login',
      },
      {
        path: '/admin',
        redirect: '/admin/login',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/admin',
    routes: [
      {
        name: '谷歌验证',
        path: '/admin/verify',
        component: './user/verify',
        menu: false,
      },
    ],
  },
  {
    path: '/dashboard',
    name: '首页',
    icon: 'dashboard',
    routes: [
      {
        path: '/dashboard',
        redirect: '/dashboard/payment',
      },
      {
        name: '支付看板',
        path: '/dashboard/payment',
        component: './dashboard/payment',
      },
      {
        name: '商户支付简报',
        path: '/dashboard/merchant',
        component: './dashboard/merchant',
      },
      {
        name: '支付通道简报',
        path: '/dashboard/channel',
        component: './dashboard/channel',
      },
      // {
      //   name: '商户环比统计',
      //   path: '/dashboard/product1',
      //   component: './dashboard/product',
      // },
      // {
      //   name: '通道环比统计',
      //   path: '/dashboard/product2',
      //   component: './dashboard/product',
      // },
      // {
      //   name: '余额统计',
      //   path: '/dashboard/balance-statistics',
      //   component: './dashboard/balance-statistics',
      // },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/merchant',
    name: '商户管理',
    icon: 'team',
    component: '../components/BaseLayout',
    routes: [
      {
        name: '商户信息',
        path: 'merchant',
        component: './merchant/merchant',
      },
      {
        name: '代理信息',
        path: 'proxy',
        component: './merchant/proxy',
      },
      {
        name: '商户通道',
        path: 'channel',
        component: './merchant/channel',
      },
      // {
      //   name: '代理提现',
      //   path: 'proxy-withdraw',
      //   component: './merchant-management/proxy-list',
      // },
      {
        name: '商户银行卡',
        path: 'bankcard',
        component: './merchant/bankcards',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/product',
    name: '通道管理',
    icon: 'menu',
    routes: [
      {
        name: '支付通道',
        path: 'payment',
        component: './product/payment',
      },
      {
        name: '代付通道',
        path: 'transfer',
        component: './product/transfer',
      },
      {
        name: '通道回调',
        path: 'notify',
        component: './product/notify',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/order',
    name: '订单管理',
    icon: 'orderedList',
    routes: [
      {
        name: '支付订单',
        path: 'payment',
        component: './order/payment',
      },
      {
        name: '代付订单',
        path: 'transfer',
        component: './order/transfer',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/audit',
    name: '流水审计',
    icon: 'accountBook',
    routes: [
      {
        name: '商户流水',
        path: 'merchant',
        component: './audit/merchant',
      },
      {
        name: '代理流水',
        path: 'proxy',
        component: './audit/proxy',
      },
      {
        name: '支付通道流水',
        path: 'channel',
        component: './audit/channel',
      },
      {
        component: '404',
      },
    ],
  },
  // {
  //   path: '/document-management',
  //   name: '文档管理',
  //   icon: 'book',
  //   routes: [
  //     {
  //       name: '文档组',
  //       path: 'groups',
  //       component: './document-management/groups',
  //     },
  //     {
  //       name: '文档管理',
  //       path: 'groups-manage',
  //       component: './document-management/document',
  //     },
  //   ],
  // },
  {
    path: '/record',
    name: '操作记录',
    icon: 'clockCircle',
    routes: [
      {
        name: '商户登录记录',
        path: 'login/merchant',
        component: './record/login-channel',
      },
      {
        name: '代理登录记录',
        path: 'login/proxy',
        component: './setting/dev',
      },
      {
        name: '管理员登录记录',
        path: 'login/admin',
        component: './record/login-admin',
      },
      {
        name: '管理员操作记录',
        path: 'operate/admin',
        component: './setting/dev',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/setting',
    name: '系统管理',
    icon: 'setting',
    routes: [
      {
        name: '支付黑名单IP',
        path: 'blackip',
        component: './setting/blackip',
      },
      {
        name: '系统配置',
        path: 'config',
        component: './setting/config',
      },
      // {
      //   name: '服务器看板',
      //   path: 'monitor/server',
      //   component: './setting/dev',
      // },
      {
        name: '数据库看板',
        path: 'monitor/database',
        component: './setting/monitor-database',
      },
      // {
      //   name: '线程池看板',
      //   path: 'monitor/threadpool',
      //   component: './setting/dev',
      // },
      // {
      //   name: '异常栈看板',
      //   path: 'monitor/error',
      //   component: './setting/dev',
      // },
      {
        name: '缓存看板',
        path: 'monitor/cache',
        component: './setting/cache',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/test',
    layout: false,
    routes: [
      {
        path: 'order',
        name: '下单测试',
        component: './test/order',
      },
      {
        path: 'test',
        name: '测试页面',
        component: './test/test',
      },
      {
        component: '404',
      },
    ],
  },
  {
    path: '/502',
    component: '502',
  },
  {
    path: '/',
    redirect: '/dashboard/payment',
  },
  {
    component: '404',
  },
];
export default routes;
