/**
 * formItem 数组 input
 */
import { PlusOutlined } from '@ant-design/icons';
import { ModalForm, ProFormMoney, ProFormText } from '@ant-design/pro-form';
import { Button, Tag } from 'antd';
import { useRef } from 'react';
import type { ProFormInstance } from '@ant-design/pro-form';
import type { ReactNode } from 'react';

interface IRangeInput {
  value?: string[];
  onChange?: (value: string[]) => void;
  label?: ReactNode;
  type?: string;
  customSymbol?: string;
}

// 校验
export const inputArrayValidator = (_: any, value: string[]) => {
  if (!value.length) {
    return Promise.reject('数据为空');
  }
  return Promise.resolve();
};

function InputArray({ value = [], onChange, label, type = 'text', customSymbol }: IRangeInput) {
  const formRef = useRef<ProFormInstance>();
  const handleAdd = async (values: { item: string }) => {
    onChange?.([...value, values.item]);
    formRef.current?.resetFields();
    return true;
  };

  const handleRemove = (index: number) => {
    const newVal = [...value];
    newVal.splice(index, 1);
    onChange?.(newVal);
  };
  return (
    <>
      {value?.map((item, index) => (
        <Tag
          style={{ marginTop: 3, marginBottom: 3 }}
          color="blue"
          closable
          key={Math.random()}
          onClose={handleRemove.bind(null, index)}
        >
          {item}
        </Tag>
      ))}

      <ModalForm
        formRef={formRef}
        autoFocusFirstInput
        width={480}
        title={<span>添加{label || '元素'}</span>}
        onFinish={handleAdd}
        trigger={<Button type="primary" icon={<PlusOutlined />} size="small" />}
      >
        {type === 'money' && (
          <ProFormMoney
            name="item"
            width={430}
            min={0}
            max={20000000}
            customSymbol={customSymbol || '¥'}
            placeholder={`请输入${label}`}
            rules={[
              {
                required: true,
                message: `请输入${label}！`,
              },
            ]}
          />
        )}
        {type === 'text' && (
          <ProFormText
            name="item"
            width={430}
            placeholder={`请输入${label}`}
            rules={[
              {
                required: true,
                message: `请输入${label}！`,
              },
            ]}
          />
        )}
      </ModalForm>
    </>
  );
}

export default InputArray;
