/**
 * formItem 输入金额范围
 */
import { Input } from 'antd';
import styles from './style.less';

interface IRangeInput {
  value?: string[];
  onChange?: (value: string[]) => void;
  lowFields?: string;
  highFields?: string;
  prefix?: string;
}

// 校验
export const rangeInputValidator = (_: any, value: number[]) => {
  const amountLimitLow = value[0];
  const amountLimitHigh = value[1];
  if (!amountLimitLow) {
    return Promise.reject('请输入单笔最低限额');
  }
  if (isNaN(amountLimitLow)) {
    return Promise.reject('单笔最低限额不是数字！');
  }
  if (!amountLimitHigh) {
    return Promise.reject('请输入单笔最高限额');
  }
  if (isNaN(amountLimitHigh)) {
    return Promise.reject('单笔最高限额不是数字！');
  }
  return Promise.resolve();
};

function RangeInput({ value = [], onChange, prefix }: IRangeInput) {
  return (
    <>
      <Input
        type="tel"
        value={value[0]}
        className={styles.limitInput}
        onChange={({ target: { value: amountLimitLow } }) => {
          onChange?.([amountLimitLow, value[1]]);
        }}
        maxLength={9}
        prefix={prefix || '￥'}
      />
      <span className={styles.waveLine}>~</span>
      <Input
        type="tel"
        value={value[1]}
        className={styles.limitInput}
        onChange={({ target: { value: amountLimitHigh } }) => {
          onChange?.([value[0], amountLimitHigh]);
        }}
        maxLength={9}
        prefix={prefix || '￥'}
      />
    </>
  );
}

export default RangeInput;
