import moment from 'moment';
import alipayImg from '@/assets/images/alipay.png';
import wechatImg from '@/assets/images/wechat.png';
import unionpayImg from '@/assets/images/unionpay.png';
import combineImg from '@/assets/images/combine.png';
import type { SizeType } from '@ant-design/pro-form/lib/BaseForm/LightWrapper';

export const ROUTER_ENUM = {
  payment: '/product/payment', // 支付通道
  transfer: '/product/transfer', // 代付通道
  orderPayment: '/order/payment', // 支付订单
  orderTransfer: '/order/transfer', // 代付订单
  productNotify: '/product/notify', // 通道回调
  merchantChannel: '/merchant/channel', // 商户管理-商户通道
  orderTest: '/test/order', // 测试下单
  loginMerchant: '/record/login/merchant', // 商户登录记录
  loginProxy: '/record/login/proxy', // 代理登录记录
  loginAdmin: '/record/login/admin', // 管理员登录记录
};

// portable 默认配置信息
export const PROTABLE_DEFAULT_SETTING = {
  pagination: {
    showSizeChanger: true,
    showQuickJumper: true,
    pageSizeOptions: ['15', '30', '50', '100'],
    defaultCurrent: 1,
    defaultPageSize: 15,
    showTotal: (total: any) => (
      <span>
        共 <span style={{ color: `var(--primaryColor)` }}>{total}</span> 条记录
      </span>
    ),
    size: 'default' as 'default',
  },
  options: { fullScreen: false, reload: false, setting: false, density: false },
  search: {
    labelWidth: 'auto' as 'auto',
  },
  rowKey: 'id',
  rowClassName: (record: any) => ('status' in record && !record.status ? 'row-disabled' : ''),
  defaultSize: 'small' as SizeType,
  form: {
    colon: false,
  },
};

// protable 没有search 和 pagination 的配置
export const PROTABLE_TABLE_ONLY_SETTING = {
  search: false as false,
  pagination: false as false,
};

// 设置默认的时间快捷选择
export const DEFAULT_DATE_RANGES = {
  今日: [moment().startOf('day'), moment()],
  昨日: [
    moment().startOf('day').subtract(1, 'days'),
    moment().startOf('day').subtract(1, 'seconds'),
  ],
  近三日: [moment().startOf('day').subtract(2, 'days'), moment()],
  本周: [moment().startOf('week').add(1, 'days'), moment().endOf('week').add(1, 'days')],
};

// 不需要登录的路由
export const NO_NEED_ROUTES = ['/document/detail'];

// 编辑相关的一些边条
export const EDIT_TYPE = {
  EDIT: 'edit',
  ADD: 'add',
};
export const EDIT_TEXT = {
  [EDIT_TYPE.EDIT]: '编辑',
  [EDIT_TYPE.ADD]: '创建',
};

// 时间查询条件
export const TIME_TYPE_ENUM = {
  ONE_MINUTE: 1,
  FIVE_MINUTES: 2,
  TEN_MINUTES: 3,
  HALF_HOUR: 4,
  ONE_HOUR: 5,
  TODAY: 10,
  YESTERDAY: 11,
  BEFORE_YESTERDAY: 12,
};

// 金融产品 icon
export const PRODUCT_ICON_ENUM = {
  alipay: alipayImg,
  wechat: wechatImg,
  unionpay: unionpayImg,
  combine: combineImg,
};
