import { DEFAULT_DATE_RANGES } from '@/constants';
import { requestMerchantOptions } from '@/services/commons';
import { requestChannelOptions } from '@/services/merchant/payment';
import type { ProColumns } from '@ant-design/pro-table';
import { Tag } from 'antd';

const ACCOUNT_TYPE = {
  1: <Tag color="success">支付账户</Tag>,
  2: <Tag color="processing">代付账户</Tag>,
};

const SERIAL_TYPE = {
  1: { text: '订单成功', color: 'green' },
  2: { text: '商户提现', color: 'blue' },
  3: { text: '代付驳回', color: 'red' },
  4: { text: '代付手续费', color: 'orange' },
  5: { text: '代付账户充值', color: 'yellow' },
  6: { text: '代付账户回退', color: 'volcano' },
  7: { text: '管理员增加', color: 'lime' },
  8: { text: '管理员扣除', color: 'purple' },
};

export const BASE_COLUMNS: ProColumns<API.ChannelFlowItem>[] = [
  {
    title: '流水ID',
    dataIndex: 'id',
    width: 90,
  },
  {
    title: '通道',
    dataIndex: 'channelId',
    hideInTable: true,
    valueType: 'select',
    request: requestChannelOptions,
    fieldProps: {
      showSearch: true,
    },
  },
  {
    title: '商户',
    dataIndex: 'mchId',
    hideInTable: true,
    valueType: 'select',
    request: requestMerchantOptions,
    fieldProps: {
      showSearch: true,
    },
  },
  {
    title: '通道ID',
    width: 65,
    dataIndex: 'channelId',
    search: false,
  },
  {
    title: '通道标识',
    search: false,
    width: 150,
    dataIndex: 'channelCode',
  },
  {
    title: '通道名称',
    search: false,
    width: 130,
    dataIndex: 'channelName',
  },
  {
    title: '商户名称',
    search: false,
    width: 100,
    dataIndex: 'mchName',
  },
  {
    title: '账户类型',
    width: 100,
    dataIndex: 'accountType',
    render: (_, record) => ACCOUNT_TYPE[record.accountType],
    valueType: 'select',
    valueEnum: {
      1: {
        text: '支付账户',
      },
      2: {
        text: '代付账户',
      },
    },
  },
  {
    title: '流水类型',
    width: 120,
    dataIndex: 'serialType',
    valueType: 'select',
    valueEnum: SERIAL_TYPE,
  },
  {
    title: '变更前余额',
    width: 120,
    search: false,
    dataIndex: 'beforeBalance',
  },
  {
    title: '变更金额',
    width: 100,
    search: false,
    dataIndex: 'auditAmount',
    render: (_, record) => (
      <strong className={record.auditAmountValue > 0 ? 'error' : 'success'}>{_}</strong>
    ),
  },
  {
    title: '变更后余额',
    width: 120,
    search: false,
    dataIndex: 'afterBalance',
  },
  {
    title: '交易金额',
    search: false,
    dataIndex: 'realAmount',
    width: 100,
  },
  {
    title: '通道费率',
    search: false,
    ellipsis: true,
    dataIndex: 'feeConfig',
    width: 150,
  },
  {
    title: '通道手续费',
    search: false,
    dataIndex: 'fee',
    width: 100,
    render: (_) => <strong className="orange">{_}</strong>,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    ellipsis: true,
    width: 300,
  },
  {
    title: '审计订单号',
    dataIndex: 'auditOrderNo',
    width: 270,
    ellipsis: true,
    copyable: true,
  },
  {
    title: '平台流水号',
    dataIndex: 'serialOrderNo',
    width: 320,
    ellipsis: true,
    copyable: true,
  },
  {
    title: '创建时间',
    dataIndex: 'auditTime',
    valueType: 'dateRange',
    hideInTable: true,
    fieldProps: { ranges: DEFAULT_DATE_RANGES },
    search: {
      transform: (value) => {
        return {
          auditTimeStart: value[0],
          auditTimeEnd: value[1],
        };
      },
    },
  },
  {
    title: '审计时间',
    dataIndex: 'auditTime',
    width: 136,
    search: false,
    ellipsis: true,
    fixed: 'right',
  },
];
