import { DEFAULT_DATE_RANGES, PRODUCT_ICON_ENUM, PROTABLE_DEFAULT_SETTING } from '@/constants';
import moment from 'moment';
import ProTable from '@ant-design/pro-table';
import type { ActionType } from '@ant-design/pro-table';
import type { ProColumns } from '@ant-design/pro-table';
import { Avatar, Space } from 'antd';
import { useRef, useEffect } from 'react';
import { requestMerchantOptions } from '@/services/commons';
import type { ProFormInstance } from '@ant-design/pro-form';
import { requestChannelOptions, requestProductOptions } from '@/services/merchant/payment';
import { requestMerchantPaymentChannelStatistics } from '@/services/dashboard/data';
import styles from './style.less';

export interface IExtraData {
  channelFee: string;
  mchBalance: string;
  mchFee: string;
  proxyFee: string;
  serialIncome: string;
  totalAmount: string;
}

function ChannelPayment() {
  const actionRef = useRef<ActionType>();
  const formRef = useRef<ProFormInstance>();

  const columns: ProColumns<API.PCStatisticsItem>[] = [
    {
      title: '商户ID',
      search: false,
      width: 65,
      dataIndex: 'productName',
      render: (text, row) => {
        // const randomColor =
        //   PRODUCT_COLOR_MAP[row.productCode] ||
        //   `bg-color-${(Math.random() * 9 + 1).toFixed(0)}`;
        return {
          children: <div>{row.mchId}</div>,
          props: {
            rowSpan: row.productRowSpan,
            className: `${styles.largeChannel} ${row.bgColor}`,
          },
        };
      },
    },
    {
      title: '商户名称',
      search: false,
      width: 100,
      dataIndex: 'mchName',
      render: (text, row) => {
        // const randomColor =
        //   PRODUCT_COLOR_MAP[row.productCode] ||
        //   `bg-color-${(Math.random() * 9 + 1).toFixed(0)}`;
        return {
          children: <div>{row.mchName}</div>,
          props: {
            rowSpan: row.productRowSpan,
            className: `${styles.largeChannel} ${row.bgColor}`,
          },
        };
      },
    },
    {
      title: '大通道名称',
      search: false,
      width: 130,
      dataIndex: 'productName',
      render: (text, row) => {
        // const randomColor =
        //   PRODUCT_COLOR_MAP[row.productCode] ||
        //   `bg-color-${(Math.random() * 9 + 1).toFixed(0)}`;
        return {
          children: <div>{row.productName}</div>,
          props: {
            rowSpan: row.productRowSpan,
            className: `${styles.largeChannel} ${row.bgColor}`,
          },
        };
      },
    },
    {
      title: '子通道名称',
      search: false,
      width: 200,
      dataIndex: 'channelName',
      render: (payMethod, record) => (
        <Space>
          <Avatar src={PRODUCT_ICON_ENUM[record.payMethod]} shape="square" size="small" />
          <span>{record.channelName}</span>
        </Space>
      ),
    },
    {
      title: '总订单数',
      search: false,
      width: 110,
      dataIndex: 'initCount',
    },
    {
      title: '失败订单数',
      search: false,
      width: 90,
      dataIndex: 'errorCount',
    },
    {
      title: '成功订单数',
      search: false,
      width: 100,
      dataIndex: 'successCount',
    },
    {
      title: '订单成功率',
      search: false,
      width: 100,
      dataIndex: 'countSuccessRate',
    },
    {
      title: '订单总金额',
      search: false,
      width: 125,
      dataIndex: 'initAmount',
    },
    {
      title: '成功总金额',
      search: false,
      width: 125,
      dataIndex: 'successAmount',
      render: (text, record) =>
        text !== '-' ? (
          <strong className={`orange ${record.successAmount !== text ? 'error' : ''}`}>
            {text}
          </strong>
        ) : (
          text
        ),
    },
    {
      title: '成功金额比例',
      search: false,
      width: 110,
      dataIndex: 'amountSuccessRate',
    },
    {
      title: '补单订单数',
      search: false,
      width: 100,
      dataIndex: 'replenishmentCount',
    },
    {
      title: '补单金额',
      search: false,
      width: 125,
      dataIndex: 'replenishmentAmount',
    },
    {
      title: '待审计订单数',
      search: false,
      width: 110,
      dataIndex: 'noAuditCount',
    },

    // 搜索项 start
    {
      title: '商户',
      dataIndex: 'mchId',
      // initialValue: initialData.mchId ? Number(initialData.mchId) : '',
      hideInTable: true,
      valueType: 'select',
      request: requestMerchantOptions,
      fieldProps: {
        showSearch: true,
      },
    },
    {
      title: '时间',
      dataIndex: 'time',
      valueType: 'dateRange',
      hideInTable: true,
      fieldProps: { ranges: DEFAULT_DATE_RANGES },
      initialValue: DEFAULT_DATE_RANGES['今日'],
      search: {
        transform: (value) => {
          return {
            startTime: value[0],
            endTime: value[1],
          };
        },
      },
    },
    {
      title: '大通道',
      dataIndex: 'productId',
      hideInTable: true,
      valueType: 'select',
      request: requestProductOptions,
      fieldProps: {
        showSearch: true,
      },
    },
    {
      title: '子通道',
      dataIndex: 'channelId',
      hideInTable: true,
      valueType: 'select',
      request: requestChannelOptions,
      fieldProps: {
        showSearch: true,
      },
    },
    // 搜索项 end
  ];

  // useEffect(() => {
  //   formRef.current?.setFieldsValue({
  //     time: DEFAULT_DATE_RANGES['今日'],
  //   });
  //   formRef.current?.submit();
  // }, []);

  return (
    <div className="m-16">
      <div className={styles.container}>
        <ProTable
          {...PROTABLE_DEFAULT_SETTING}
          pagination={false}
          scroll={{ x: 1420, y: 'calc(100vh - 220px)' }}
          columns={columns}
          request={requestMerchantPaymentChannelStatistics}
          actionRef={actionRef}
          formRef={formRef}
          defaultSize="small"
        />
      </div>
    </div>
  );
}

export default ChannelPayment;
