import { Progress } from '@ant-design/charts';
import { Col, Row } from 'antd';

import { useRequest } from 'umi';
import numeral from 'numeral';
import { ChartCard, Field } from './Charts';
import { getBasicData } from '@/services/dashboard/data';
import Trend from './Trend';
import Yuan from '../utils/Yuan';
import styles from '../style.less';
import { getColor } from './SuccessRate';

const topColResponsiveProps = {
  xs: 24,
  sm: 12,
  md: 12,
  lg: 12,
  xl: 12,
  style: { marginBottom: 12 },
};

const showFlag = (num: number) => (num > 0 ? 'up' : 'down');

const IntroduceRow = () => {
  const {
    data = {} as API.analysisItem,
    error,
    loading,
  } = useRequest<{
    data: API.analysisItem;
  }>(getBasicData);

  if (error) return <div>出错了...</div>;
  return (
    <Row gutter={24}>
      <Col {...topColResponsiveProps}>
        <ChartCard
          bordered={false}
          title="今日支付成功总额"
          // action={
          //   <Tooltip title="指标说明">
          //     <InfoCircleOutlined />
          //   </Tooltip>
          // }
          loading={loading}
          total={() => <Yuan>{data.todayTotalPayAmount}</Yuan>}
          footer={
            <Field label="昨日支付成功总额" value={<Yuan>{data.yesterdayTotalPayAmount}</Yuan>} />
          }
          contentHeight={46}
        >
          <Trend flag={showFlag(data.dodTotalPayAmountRate)} style={{ marginRight: 16 }}>
            日同比
            <span className={styles.trendText}>{Math.abs(data.dodTotalPayAmountRate || 0)}%</span>
          </Trend>
          {/* <Trend flag={showFlag(data.hohTotalPayAmountRate)}>
            时同比
            <span className={styles.trendText}>{Math.abs(data.hohTotalPayAmountRate)}%</span>
          </Trend> */}
        </ChartCard>
      </Col>

      <Col {...topColResponsiveProps}>
        <ChartCard
          loading={loading}
          bordered={false}
          title="今日支付成功率"
          // action={
          //   <Tooltip title="指标说明">
          //     <InfoCircleOutlined />
          //   </Tooltip>
          // }
          total={`${data.todaySuccessRate}%`}
          footer={<Field label="昨日支付成功率" value={`${data.yesterdaySuccessRate || 0}%`} />}
          contentHeight={46}
        >
          <Progress
            height={46}
            percent={(data.todaySuccessRate || 0) / 100}
            color={getColor((data.todaySuccessRate || 0) / 100)}
            forceFit
            size={8}
          />
        </ChartCard>
      </Col>
    </Row>
  );
};

export default IntroduceRow;
