import { Card, Col, Row, Tabs } from 'antd';
import { Column } from '@ant-design/charts';

import numeral from 'numeral';
import styles from '../style.less';

import type { ITimeType } from '@/constants/types';

const { TabPane } = Tabs;

const SuccessAmount = ({
  data,
  isActive,
  loading,
  selectDate,
}: {
  isActive: (key: ITimeType) => string;
  data: API.AnalysisChartItem;
  loading: boolean;
  selectDate: (key: ITimeType) => void;
}) => (
  <Card loading={loading} bordered={false} bodyStyle={{ padding: 0 }}>
    <div className={styles.salesCard}>
      <Tabs
        tabBarExtraContent={
          <div className={styles.salesExtraWrap}>
            <div className={styles.salesExtra}>
              <a className={isActive('TEN_MINUTES')} onClick={() => selectDate('TEN_MINUTES')}>
                10分钟
              </a>
              <a className={isActive('HALF_HOUR')} onClick={() => selectDate('HALF_HOUR')}>
                30分钟
              </a>
              <a className={isActive('ONE_HOUR')} onClick={() => selectDate('ONE_HOUR')}>
                1小时
              </a>
              <a className={isActive('TODAY')} onClick={() => selectDate('TODAY')}>
                今天
              </a>
              <a className={isActive('YESTERDAY')} onClick={() => selectDate('YESTERDAY')}>
                昨天
              </a>
              <a
                className={isActive('BEFORE_YESTERDAY')}
                onClick={() => selectDate('BEFORE_YESTERDAY')}
              >
                前天
              </a>
            </div>
          </div>
        }
        size="large"
        tabBarStyle={{ marginBottom: 12 }}
      >
        <TabPane tab="通道支付成功总额" key="payment">
          <Row>
            <Col xl={16} lg={12} md={12} sm={24} xs={24}>
              <div className={styles.salesBar}>
                <Column
                  height={300}
                  forceFit
                  data={data.channelSuccessAmount}
                  xField="name"
                  yField="value"
                  xAxis={{
                    visible: true,
                    title: {
                      visible: false,
                    },
                  }}
                  yAxis={{
                    visible: true,
                    title: {
                      visible: false,
                    },
                  }}
                  meta={{
                    value: {
                      alias: '成功总额',
                      formatter: (v) => {
                        return `${v}元`;
                      },
                    },
                  }}
                  padding={[7, 0, 25, 60]}
                />
              </div>
            </Col>
            <Col xl={8} lg={12} md={12} sm={24} xs={24}>
              <div className={styles.salesRank}>
                <h4 className={styles.rankingTitle}>商户支付成功总额排名</h4>
                <ul className={styles.rankingList}>
                  {data.merchantSuccessAmount?.map((item, i) => (
                    <li key={item.name}>
                      <span className={`${styles.rankingItemNumber} ${i < 3 ? styles.active : ''}`}>
                        {i + 1}
                      </span>
                      <span className={styles.rankingItemTitle} title={item.name}>
                        {item.name}
                      </span>
                      <span className={styles.rankingItemValue}>
                        {numeral(item.value).format('0,0')}元
                      </span>
                    </li>
                  ))}
                </ul>
              </div>
            </Col>
          </Row>
        </TabPane>
        {/* <TabPane tab="代付" key="transfer">
          开发中...
        </TabPane> */}
      </Tabs>
    </div>
  </Card>
);

export default SuccessAmount;
