import { Card, Col, Row, Tabs } from 'antd';
import { RingProgress } from '@ant-design/charts';

import NumberInfo from './NumberInfo';
import styles from '../style.less';

export const getColor = (percent: number) => {
  if (percent < 0.7) {
    return '#ff4d4f';
  }
  if (percent <= 0.8) {
    return '#1890ff';
  }
  return '#52c41a';
};

const CustomTab = ({ data }: { data: API.ChartItem }) => (
  <Row gutter={8} style={{ width: 190, margin: '8px 0' }}>
    <Col span={12}>
      <NumberInfo
        title={data.name}
        subTitle="成功率"
        gap={2}
        total={`${data.value}%`}
        theme={undefined}
      />
    </Col>
    <Col span={12} style={{ paddingTop: 36 }}>
      <RingProgress
        color={getColor(data.value / 100)}
        height={60}
        width={60}
        percent={data.value / 100}
      />
    </Col>
  </Row>
);

const { TabPane } = Tabs;

const SuccessRate = ({ loading, data }: { loading: boolean; data: API.ChartItem[] }) => (
  <Card loading={loading} className={styles.offlineCard} bordered={false} style={{ marginTop: 12 }}>
    <Tabs>
      {data.map((item) => (
        <TabPane tab={<CustomTab data={item} />} key={item.name} />
      ))}
    </Tabs>
  </Card>
);

export default SuccessRate;
