import { useState } from 'react';
import { GridContent } from '@ant-design/pro-layout';
import IntroduceRow from './components/IntroduceRow';
import SuccessAmount from './components/SuccessAmount';
import SuccessRate from './components/SuccessRate';
import { useRequest } from 'umi';

import styles from './style.less';
import { getChart } from '@/services/dashboard/data';
import { TIME_TYPE_ENUM } from '@/constants';
import type { ITimeType } from '@/constants/types';

const Analysis = () => {
  const [activeTimeType, setActiveTimeType] = useState<ITimeType>('TODAY');

  const { loading, data, run } = useRequest(getChart);

  const selectDate = async (type: ITimeType) => {
    const lastTimeType = activeTimeType;
    setActiveTimeType(type);
    const result = await run(TIME_TYPE_ENUM[type]);
    if (!result) {
      setActiveTimeType(lastTimeType);
    }
  };

  const isActive = (type: ITimeType) => {
    if (!activeTimeType) {
      return '';
    }
    if (type === activeTimeType) {
      return styles.currentDate;
    }
    return '';
  };

  return (
    <GridContent>
      <>
        <IntroduceRow />
        <SuccessAmount
          data={data || {}}
          isActive={isActive}
          loading={loading}
          selectDate={selectDate}
        />

        <SuccessRate loading={loading} data={data?.channelSuccessRate || []} />
      </>
    </GridContent>
  );
};

export default Analysis;
