import { useRef } from 'react';
import ProTable from '@ant-design/pro-table';
import type { ProColumns, ActionType } from '@ant-design/pro-table';
import { PROTABLE_DEFAULT_SETTING } from '@/constants';
import { requestMerchantBankcardList } from '@/services/merchant/merchant';
import { requestBankcardOptions, requestMerchantOptions } from '@/services/commons';

function Bankcards() {
  const actionRef = useRef<ActionType>();
  const columns: ProColumns<API.BankcardItem>[] = [
    {
      title: '商户ID',
      width: 70,
      dataIndex: 'mchId',
      search: false,
    },
    {
      title: '商户',
      dataIndex: 'mchId',
      valueType: 'select',
      request: requestMerchantOptions,
      fieldProps: {
        showSearch: true,
      },
      hideInTable: true,
    },
    {
      title: '商户银行卡',
      dataIndex: 'bankCode',
      valueType: 'select',
      request: requestBankcardOptions,
      fieldProps: {
        showSearch: true,
      },
      hideInTable: true,
    },
    {
      title: '商户名称',
      width: 100,
      dataIndex: 'mchName',
      search: false,
    },
    {
      title: '所属银行',
      width: 160,
      search: false,
      dataIndex: 'bankCode/bankName',
      render: (_, record) => (
        <span>
          {record.bankCode}/{record.bankName}
        </span>
      ),
    },
    {
      title: '支行',
      width: 120,
      search: false,
      dataIndex: 'subBank',
      // copyable: true,
    },
    {
      title: '账户名',
      width: 100,
      dataIndex: 'accountName',
    },
    {
      title: '账户号',
      dataIndex: 'accountNumber',
      width: 330,
      copyable: true,
    },
    {
      title: '备注',
      width: 140,
      ellipsis: true,
      search: false,
      dataIndex: 'memo',
    },
    {
      title: '创建时间',
      search: false,
      dataIndex: 'createTime',
      width: 135,
    },
  ];
  return (
    <div>
      <ProTable
        {...PROTABLE_DEFAULT_SETTING}
        scroll={{ x: 1000, y: 'calc(100vh - 280px)' }}
        columns={columns}
        request={requestMerchantBankcardList}
        actionRef={actionRef}
      />
    </div>
  );
}

export default Bankcards;
