import { ModalForm, ProFormMoney } from '@ant-design/pro-form';
import { message } from 'antd';
import { EditTwoTone } from '@ant-design/icons';
import { updatePaymentChannelDayLimitAmount } from '@/services/merchant/channelPayment';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  initialData: API.MerchantChannelItem;
  refresh?: any;
}

function ModalFormDayLimitAmount({ initialData, refresh }: IProps) {
  const handleFinish = async (values: { dayLimitAmountValue: number }) => {
    const res = await updatePaymentChannelDayLimitAmount(
      initialData.id,
      values.dayLimitAmountValue,
    );
    if (res.code === '0000') {
      refresh?.();
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ModalForm
        {...formItemLayout}
        title="编辑日总限额"
        layout="horizontal"
        width={520}
        trigger={<EditTwoTone />}
        onFinish={handleFinish}
        initialValues={initialData}
      >
        <ProFormMoney
          width={250}
          name="dayLimitAmountValue"
          min={0}
          max={20000000}
          placeholder="请输入日总限额"
          label="日总限额"
          customSymbol={initialData.currencyMark || '¥'}
          rules={[{ required: true, message: '请输入日总限额!' }]}
        />
      </ModalForm>
    </div>
  );
}

export default ModalFormDayLimitAmount;
