import { ModalForm, ProFormDependency, ProFormDigit, ProFormRadio } from '@ant-design/pro-form';
import { message } from 'antd';
import { EditTwoTone } from '@ant-design/icons';
import { updatePaymentChannelFee } from '@/services/merchant/channelTransfer';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
  wrapperCol: {
    sm: { span: 16 },
  },
};

interface IProps {
  initialData: API.MerchantChannelItem;
  refresh?: any;
}

const showFeeFix = (feeType: number) => [2, 3].includes(feeType);
const showFeeRate = (feeType: number) => [1, 3].includes(feeType);

function ModalFormFee({ initialData, refresh }: IProps) {
  const handleFinish = async (values: API.MerchantChannelItem) => {
    const res = await updatePaymentChannelFee(initialData.id, values);
    if (res.code === '0000') {
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ModalForm
        {...formItemLayout}
        title="编辑费率"
        layout="horizontal"
        width={520}
        trigger={<EditTwoTone />}
        onFinish={handleFinish}
        initialValues={initialData}
      >
        <ProFormRadio.Group
          name="feeType"
          label="收费方式"
          options={[
            {
              label: '指定费率',
              value: 1,
            },
            {
              label: '单笔固额',
              value: 2,
            },
            {
              label: '组合收费',
              value: 3,
            },
          ]}
          rules={[{ required: true, message: '请选择收费方式!' }]}
        />
        <ProFormDependency name={['feeType']}>
          {({ feeType }) => {
            return (
              <>
                {showFeeRate(feeType) && (
                  <ProFormDigit
                    name="feeRate"
                    min={1}
                    max={100}
                    fieldProps={{ addonAfter: '%' }}
                    placeholder="请输入通道费率"
                    label="通道费率"
                    required
                    rules={[
                      ({ getFieldValue }) => ({
                        validator(_, value) {
                          const feeTypeValue = getFieldValue('feeType');
                          if (!value && showFeeRate(feeTypeValue)) {
                            return Promise.reject('请输入通道费率!');
                          }
                          return Promise.resolve();
                        },
                      }),
                    ]}
                  />
                )}
                {showFeeFix(feeType) && (
                  <ProFormDigit
                    name="feeFix"
                    min={1}
                    max={20000000}
                    fieldProps={{ addonAfter: '元' }}
                    placeholder="请输入单笔费用"
                    label="单笔费用"
                    required
                    rules={[
                      ({ getFieldValue }) => ({
                        validator(_, value) {
                          const feeTypeValue = getFieldValue('feeType');
                          if (!value && showFeeFix(feeTypeValue)) {
                            return Promise.reject('请输入单笔费用!');
                          }
                          return Promise.resolve();
                        },
                      }),
                    ]}
                  />
                )}
              </>
            );
          }}
        </ProFormDependency>
      </ModalForm>
    </div>
  );
}

export default ModalFormFee;
