import { ModalForm, ProFormDigit } from '@ant-design/pro-form';
import { message } from 'antd';
import { EditTwoTone } from '@ant-design/icons';
import { updatePaymentChannelWeight } from '@/services/merchant/channelTransfer';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  initialData: API.MerchantChannelItem;
  refresh?: any;
}

function ModalFormWeight({ initialData, refresh }: IProps) {
  const handleFinish = async (values: { weight: number }) => {
    const res = await updatePaymentChannelWeight(initialData.id, values.weight);
    if (res.code === '0000') {
      refresh?.();
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ModalForm
        {...formItemLayout}
        title="编辑权重"
        layout="horizontal"
        width={520}
        trigger={<EditTwoTone />}
        onFinish={handleFinish}
        initialValues={initialData}
      >
        <ProFormDigit
          width={250}
          name="weight"
          min={1}
          max={10}
          placeholder="请输入权重"
          label="权重"
          rules={[{ required: true, message: '请输入权重!' }]}
        />
      </ModalForm>
    </div>
  );
}

export default ModalFormWeight;
