import { useState } from 'react';
import { history } from 'umi';
import { Tabs } from 'antd';
import { ROUTER_ENUM } from '@/constants';
import ChannelPayment from './components/ChannelPayment';
import ChannelTransfer from './components/ChannelTransfer';
import styles from './style.less';

const { TabPane } = Tabs;
const TAB_KEY = {
  PAYMENT: '1',
  TRANSFER: '2',
};

function Channel({ location: { query } }: any) {
  const [activeKey, setActiveKey] = useState<string>(query.tabKey || TAB_KEY.PAYMENT);
  const handleTabChange = (tabKey: string) => {
    setActiveKey(tabKey);
    const newQuery = {
      ...query,
      tabKey,
    };

    // 去掉mchId
    if (newQuery.mchId) {
      delete newQuery.mchId;
    }

    history.replace({
      pathname: ROUTER_ENUM.merchantChannel,
      query: newQuery,
    });
  };

  return (
    <div className={styles.container}>
      <Tabs activeKey={activeKey} onChange={handleTabChange} className={styles.container}>
        <TabPane tab="支付通道" key={TAB_KEY.PAYMENT}>
          {activeKey === TAB_KEY.PAYMENT && <ChannelPayment initialData={query} />}
        </TabPane>
        <TabPane tab="代付通道" key={TAB_KEY.TRANSFER}>
          {activeKey === TAB_KEY.TRANSFER && <ChannelTransfer initialData={query} />}
        </TabPane>
      </Tabs>
    </div>
  );
}

export default Channel;
