import { useRef } from 'react';
import ProForm, { ProFormSelect, ProFormSwitch, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { Button, message, Row, Col, Space } from 'antd';
import { requestProxyOptions } from '@/services/commons';
import { editMerchantBasic } from '@/services/merchant/merchant';

interface IProps {
  data: API.MerchantItem;
  onCancel: () => void;
  refresh: () => void;
}

const formItemLayout = {
  labelCol: {
    span: 4,
  },
  wrapperCol: {
    span: 18,
  },
};
const subFormItemLayout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 14,
  },
};

function FormCommon({ data, onCancel, refresh }: IProps) {
  const formRef = useRef<ProFormInstance>();
  const handleFinish = async (values: any) => {
    const params = { id: data.id, ...values, status: values.status ? 1 : 0 };
    const res = await editMerchantBasic(params);
    if (res.code === '0000') {
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ProForm
        {...formItemLayout}
        formRef={formRef}
        layout="horizontal"
        initialValues={{ ...data, status: data.status ? 1 : 0 }}
        onFinish={handleFinish}
        submitter={{
          searchConfig: { submitText: '确认' },
          render: (props, doms) => {
            return (
              <Space style={{ width: '100%', justifyContent: 'flex-end' }}>
                <Button onClick={onCancel}>取消</Button>
                {doms[1]}
              </Space>
            );
          },
        }}
        // onReset={handleReset}
      >
        <Row>
          <Col span={12}>
            <ProFormText
              {...subFormItemLayout}
              name="mchName"
              placeholder="请输入商户名称"
              rules={[{ required: true, message: '请输入商户名称！' }]}
              label="商户名称"
            />
          </Col>
          <Col span={11}>
            <ProFormText {...subFormItemLayout} name="loginName" label="登录名称" readonly />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormSelect
              {...subFormItemLayout}
              name="proxyId"
              placeholder="请选择上级代理"
              label="上级代理"
              request={requestProxyOptions}
            />
          </Col>
          <Col span={11}>
            <ProFormText
              {...subFormItemLayout}
              name="groupName"
              label="分组名称"
              placeholder="请输入分组名称"
            />
          </Col>
        </Row>

        <Row>
          <Col span={12}>
            <ProFormSwitch
              {...subFormItemLayout}
              name="status"
              label="状态"
              checkedChildren="启用"
              unCheckedChildren="禁用"
            />
          </Col>
          <Col span={11}>
            <ProFormSwitch
              {...subFormItemLayout}
              name="googleStatus"
              label="谷歌验证"
              checkedChildren="启用"
              unCheckedChildren="禁用"
            />
          </Col>
        </Row>
      </ProForm>
    </div>
  );
}

export default FormCommon;
