import { useRef } from 'react';
import { DrawerForm, ProFormSelect, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { Alert, message } from 'antd';
import { googleSMSValidate } from '@/utils/validators';
import { clearMerchant } from '@/services/merchant/merchant';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  refresh?: any;
  type?: string;
  data?: API.MerchantItem;
}

function ModalFormClear({ refresh, data }: IProps) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: any) => {
    const res = await clearMerchant({
      id: data?.id || '',
      googleCode: values.googleCode,
      timeType: values.timeType,
    });
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`清除数据成功`);
      return true;
    }
    return false;
  };

  const handleVisibleChange = (visible: boolean) => {
    if (visible) {
      formRef.current?.setFieldsValue({ ...data });
    }
  };

  return (
    <div>
      <DrawerForm
        {...formItemLayout}
        formRef={formRef}
        title="清除商户数据"
        layout="horizontal"
        width={520}
        trigger={<a>清除数据</a>}
        onFinish={handleFinish}
        onVisibleChange={handleVisibleChange}
        initialValues={data}
      >
        <Alert message="删除商户数据前，请确保商户订单已审计并已完成结算！！！" type="warning" />
        <br />
        <ProFormText name="id" label="商户ID" readonly required width={500} />
        <ProFormText name="mchName" label="商户名称" readonly required width={500} />
        <ProFormSelect
          width={200}
          name="timeType"
          label="时间范围"
          valueEnum={{
            1: '全部',
            '-1': '一天前',
            '-3': '三天前',
            '-7': '一周前',
          }}
          rules={[{ required: true, message: '请选择时间范围!' }]}
        />
        <ProFormText
          name="googleCode"
          fieldProps={{ maxLength: 6 }}
          label="谷歌验证"
          width={200}
          placeholder="请输入谷歌验证"
          rules={[
            {
              required: true,
              validator: googleSMSValidate,
            },
          ]}
        />
      </DrawerForm>
    </div>
  );
}

export default ModalFormClear;
