import { useRequest } from 'umi';
import { Spin, Tabs } from 'antd';
import FormCommon from './FormCommon';
import FormSecurity from './FormSecurity';
import FormLogin from './FormLogin';
import { getMerchantDetail } from '@/services/merchant/merchant';

interface IProps {
  data: API.MerchantItem;
  onCancel: () => void;
  refresh: any;
}

const { TabPane } = Tabs;
const TAB_ENUM = {
  COMMON: 'common',
  SECURITY: 'security',
  LOGIN: 'login',
};
const TAB_MAP = {
  [TAB_ENUM.COMMON]: '常规',
  [TAB_ENUM.SECURITY]: '接入',
  [TAB_ENUM.LOGIN]: '安全',
};

function ModalFormEdit({ data: record, onCancel, refresh: refreshParent }: IProps) {
  const { data, loading, run } = useRequest(getMerchantDetail.bind(null, record.id));
  console.log('data: ', data);

  const refresh = () => {
    refreshParent?.();
    run();
  };

  return (
    <Spin spinning={loading}>
      <Tabs>
        <TabPane tab={TAB_MAP[TAB_ENUM.COMMON]} key={TAB_ENUM.COMMON}>
          {data && <FormCommon data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.SECURITY]} key={TAB_ENUM.SECURITY}>
          <FormSecurity data={data} onCancel={onCancel} refresh={refresh} />
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.LOGIN]} key={TAB_ENUM.LOGIN}>
          {data && <FormLogin data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
      </Tabs>
    </Spin>
  );
}

export default ModalFormEdit;
