import { syncMerchant } from '@/services/merchant/merchant';
import type { ISyncMerchantParams } from '@/services/merchant/merchant';
import { DrawerForm, ProFormSelect } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { Alert, Button, message } from 'antd';
import { useRef } from 'react';
import { requestMerchantOptions } from '@/services/commons';
import styles from '../style.less';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  refresh?: () => void | undefined;
}

function ModalFormSync({ refresh }: IProps) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: ISyncMerchantParams) => {
    const res = await syncMerchant({ ...values });
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`同步成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <DrawerForm
        {...formItemLayout}
        formRef={formRef}
        title="商户通道同步"
        layout="horizontal"
        width={720}
        trigger={<Button type="primary">同步商户</Button>}
        onFinish={handleFinish}
      >
        <Alert
          className={styles.alert}
          message={
            <div>
              <p style={{ marginBottom: 5 }}>1. 同步将删除目标原先所有存在的子通道。</p>
              <p style={{ margin: 0 }}>2. 目标商户的通道费率将于来源商户一致。</p>
            </div>
          }
          type="error"
        />

        <ProFormSelect
          width={500}
          name="srcMchId"
          placeholder="请选择来源商户"
          label="来源商户"
          rules={[{ required: true, message: '请选择来源商户!' }]}
          request={requestMerchantOptions}
        />
        <ProFormSelect
          width={500}
          name="targetMchIds"
          placeholder="请选择同步商户"
          label="同步商户"
          required
          mode="multiple"
          rules={[{ required: true, message: '请选择目标商户!' }]}
          request={requestMerchantOptions}
        />
      </DrawerForm>
    </div>
  );
}

export default ModalFormSync;
