import { PlusOutlined } from '@ant-design/icons';
import { DrawerForm, ProFormSwitch, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { Button, message, Modal } from 'antd';
import { useRef } from 'react';
import { addProxy, updateProxy } from '@/services/merchant/proxy';
import AccountInfo from './AccountInfo';
import { EDIT_TEXT, EDIT_TYPE } from '@/constants';
import styles from '../style.less';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

function ModalFormAdd({ refresh, type = EDIT_TYPE.ADD, data }: any) {
  const formRef = useRef<ProFormInstance>();

  const showAccoutInfo = (info: API.AccountInfo) => {
    Modal.info({
      className: styles.infoModal,
      width: 500,
      content: <AccountInfo data={info} />,
    });
  };

  const handleFinish = async (values: API.ProxyItem) => {
    let res;
    if (type === EDIT_TYPE.EDIT) {
      res = await updateProxy({
        ...data,
        ...values,
        status: values.status ? 1 : 0,
      });
    } else {
      res = await addProxy({ ...values });
    }
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`${EDIT_TEXT[type]}成功`);
      if (type === EDIT_TYPE.ADD) {
        showAccoutInfo(res.data);
      }
      return true;
    }
    return false;
  };

  const handleVisibleChange = (visible: boolean) => {
    if (visible) {
      if (type === EDIT_TYPE.EDIT) {
        formRef.current?.setFieldsValue({ ...data, status: !!data.status });
      }
    }
  };

  return (
    <div>
      <DrawerForm
        {...formItemLayout}
        formRef={formRef}
        title={`${EDIT_TEXT[type]}代理`}
        layout="horizontal"
        width={720}
        trigger={
          type === EDIT_TYPE.ADD ? (
            <Button icon={<PlusOutlined />} type="primary">
              创建代理
            </Button>
          ) : (
            <a>编辑</a>
          )
        }
        onFinish={handleFinish}
        onVisibleChange={handleVisibleChange}
        initialValues={type === EDIT_TYPE.EDIT ? { ...data, status: !!data.status } : {}}
      >
        <ProFormText
          name="proxyName"
          placeholder="请输入代理名称"
          label="代理名称"
          width={500}
          rules={[{ required: true, message: '请输入代理名称!' }]}
        />
        <ProFormText
          name="loginName"
          label="登录名称"
          placeholder="请输入登录名称"
          width={500}
          disabled={type === EDIT_TYPE.EDIT}
          rules={[
            {
              required: true,
              message: '请输入登录名称！',
            },
          ]}
        />
        {type === EDIT_TYPE.EDIT && (
          <ProFormSwitch
            name="status"
            label="状态"
            checkedChildren="启用"
            unCheckedChildren="禁用"
          />
        )}
      </DrawerForm>
    </div>
  );
}

export default ModalFormAdd;
