import { EditTwoTone } from '@ant-design/icons';
import { ModalForm, ProFormDigit } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { message, Tooltip } from 'antd';
import { useRef } from 'react';
import { editProxyPaymentProductRate } from '@/services/merchant/proxy';
import { EDIT_TEXT, EDIT_TYPE } from '@/constants';

const formItemLayout = {
  labelCol: {
    style: {
      // width: '104px',
    },
  },
};

function ModalFormEditRate({ refresh, type = EDIT_TYPE.EDIT, data }: any) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: API.PaymentProductItem) => {
    const res = await editProxyPaymentProductRate(
      data.proxyId,
      data.productId,
      values.feeRateValue as string,
    );
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`${EDIT_TEXT[type]}成功`);
      return true;
    }
    return false;
  };

  const handleVisibleChange = (visible: boolean) => {
    if (visible) {
      if (type === EDIT_TYPE.EDIT) {
        formRef.current?.setFieldsValue({ ...data, status: !!data.status });
      }
    }
  };

  return (
    <div>
      <ModalForm
        {...formItemLayout}
        formRef={formRef}
        autoFocusFirstInput
        title="编辑费率"
        layout="horizontal"
        width={420}
        trigger={
          <Tooltip title="编辑费率">
            <a>
              <EditTwoTone />
            </a>
          </Tooltip>
        }
        onFinish={handleFinish}
        onVisibleChange={handleVisibleChange}
        initialValues={type === EDIT_TYPE.EDIT ? { ...data, status: !!data.status } : {}}
      >
        <ProFormDigit
          name="feeRateValue"
          placeholder="请输入费率"
          label="费率"
          rules={[{ required: true, message: '请输入费率!' }]}
          addonAfter="%"
        />
      </ModalForm>
    </div>
  );
}

export default ModalFormEditRate;
