import { useRef } from 'react';
import { PROTABLE_DEFAULT_SETTING, PROTABLE_TABLE_ONLY_SETTING } from '@/constants';
import {
  requestProxyPaymentProductList,
  switchProxyPaymentProductStatus,
} from '@/services/merchant/proxy';
import ProTable from '@ant-design/pro-table';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import { message, Space, Switch } from 'antd';
import ModalFormEditRate from './ModalFormEditRate';

interface IProps {
  id: string;
}

function PaymentProduct({ id }: IProps) {
  const actionRef = useRef<ActionType>();

  // 切换状态
  const switchStatus = async (productId: string, status: number) => {
    const text = status === 0 ? '禁用' : '启用';
    const res = await switchProxyPaymentProductStatus(id, productId, status);
    if (res?.code === '0000') {
      actionRef.current?.reload?.();
      message.success(`${text}成功`);
    }
  };

  const columns: ProColumns<API.PaymentProductItem>[] = [
    {
      title: '通道编码',
      width: 180,
      dataIndex: 'productCode',
    },
    {
      title: '通道名称',
      width: 180,
      dataIndex: 'productName',
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: 80,
      render: (_, record) => {
        const { status } = record;
        return (
          <Switch
            // disabled={!googleStatus}
            checkedChildren="启用"
            unCheckedChildren="禁用"
            checked={!!status}
            onClick={switchStatus.bind(null, record.productId as string, status === 0 ? 1 : 0)}
          />
        );
      },
    },
    {
      title: '过期时间',
      dataIndex: 'expireTime',
      width: 135,
    },
    {
      title: '费率',
      dataIndex: 'feeRate',
      width: 90,
      render: (_, record) => {
        return (
          <Space>
            {_}
            <ModalFormEditRate data={record} refresh={actionRef.current?.reload} />
          </Space>
        );
      },
    },
  ];

  return (
    <div>
      <ProTable
        {...PROTABLE_DEFAULT_SETTING}
        {...PROTABLE_TABLE_ONLY_SETTING}
        request={requestProxyPaymentProductList.bind(null, id)}
        scroll={{ y: 'calc(100vh - 300px)' }}
        actionRef={actionRef}
        columns={columns}
      />
    </div>
  );
}

export default PaymentProduct;
