import { Select, Switch } from 'antd';
import { useState } from 'react';
import styles from '../style.less';

let interval: any = null;
const { Option } = Select;
interface IProps {
  refresh?: () => Promise<void>;
}

function AutoRefresh({ refresh }: IProps) {
  const [countdownValue, setCountdownValue] = useState<number>(5e3);
  const [autoRefreshed, setAutoRefreshed] = useState<boolean>(false);

  const switchRefresh = (checked: boolean) => {
    setAutoRefreshed(checked);
    if (checked) {
      if (interval) {
        clearInterval(interval);
      }

      interval = setInterval(() => {
        refresh?.();
      }, countdownValue);
    } else if (interval) {
      clearInterval(interval);
    }
  };

  return (
    <div className={styles.refreshContainer} key="refresh">
      {autoRefreshed && (
        <>
          <span className={styles.refreshTitle}>刷新频率：</span>
          <Select
            size="small"
            value={countdownValue}
            style={{ width: 70 }}
            onChange={(v) => {
              if (autoRefreshed) {
                if (interval) {
                  clearInterval(interval);
                }
                interval = setInterval(() => {
                  refresh?.();
                }, v);
              }
              setCountdownValue(v);
            }}
          >
            <Option value={5e3}>5秒</Option>
            <Option value={15e3}>15秒</Option>
            <Option value={30e3}>30秒</Option>
          </Select>
        </>
      )}
      &nbsp;&nbsp;&nbsp; 自动刷新：
      <Switch
        checked={autoRefreshed}
        onClick={switchRefresh}
        checkedChildren="开启"
        unCheckedChildren="关闭"
      />
    </div>
  );
}

export default AutoRefresh;
