import { formatJSON } from '@/utils';
import { Badge, Col, Row, Tag, Typography } from 'antd';
import { Controlled as CodeMirror } from 'react-codemirror2';
import { TRANSACTION_STATUS_MAP } from '../constants';
import styles from '../style.less';

const { Text } = Typography;

interface IProps {
  orderResult: Partial<API.OrderResultItem>;
}

function OrderResult({
  orderResult: {
    errMsg,
    serialOrderNo,
    mchOrderNo,
    channelOrderNo,
    success,
    status,
    realAmount,
    rawInfo,
  },
}: IProps) {
  return (
    <div className={styles.orderResult}>
      <Row>
        <Col span={24}>
          查询结果：
          {success ? (
            <Badge status="success" text="查询成功" />
          ) : (
            <Badge status="error" text="查询失败" />
          )}
        </Col>
      </Row>
      <Row>
        <Col span={24}>
          商户交易号：<Text copyable={!!mchOrderNo}>{mchOrderNo}</Text>
        </Col>
      </Row>
      <Row>
        <Col span={24}>
          平台流水号：<Text copyable={!!serialOrderNo}>{serialOrderNo}</Text>
        </Col>
      </Row>
      <Row>
        <Col span={24}>
          通道订单号：<Text copyable={!!channelOrderNo}>{channelOrderNo}</Text>
        </Col>
      </Row>
      {success ? (
        <>
          <Row>
            <Col span={24}>
              交易状态：
              {status && (
                <Tag color={TRANSACTION_STATUS_MAP[status].status}>
                  {TRANSACTION_STATUS_MAP[status].text}
                </Tag>
              )}
            </Col>
          </Row>
          <Row>
            <Col span={24}>
              交易金额：<strong className="orange">{realAmount}</strong>
            </Col>
          </Row>
        </>
      ) : (
        <>
          <Row>
            <Col span={24}>
              错误信息：<span className="error">{errMsg}</span>
            </Col>
          </Row>
        </>
      )}
      <Row>
        <Col span={24}>
          响应结果：
          <Text copyable={!!rawInfo ? { text: rawInfo } : false} />
        </Col>
        <CodeMirror
          className={styles.codeMirror}
          value={formatJSON(rawInfo || '')}
          options={{
            mode: 'application/json',
            theme: 'idea',
            lineNumbers: true,
          }}
          onBeforeChange={() => {}}
        />
      </Row>
    </div>
  );
}

export default OrderResult;
