import { useEffect, useState } from 'react';
import { getChannelReqLog } from '@/services/merchant/transfer';
import { Col, Row, Spin, Tag, Typography } from 'antd';
import 'codemirror/lib/codemirror';
import 'codemirror/lib/codemirror.css';
import 'codemirror/mode/javascript/javascript'; // js
import 'codemirror/theme/idea.css';
import { Controlled as CodeMirror } from 'react-codemirror2';
import { formatJSON } from '@/utils';
import styles from '../style.less';

const { Text } = Typography;

interface IProps {
  serialOrderNo: string;
}
function ChannelInfo({ serialOrderNo }: IProps) {
  const [loading, setLoading] = useState<any>(false);
  const [data, setData] = useState<Partial<API.ChannelReqInfo>>({});
  useEffect(() => {
    const init = async () => {
      setLoading(true);
      const res = await getChannelReqLog(serialOrderNo);
      setLoading(false);
      if (res?.code === '0000') {
        setData(res.data);
      }
    };
    if (serialOrderNo) {
      init();
    }
  }, [serialOrderNo]);

  return (
    <Spin spinning={loading}>
      <div className={styles.info}>
        <Row>
          <Col span={12}>通道名称：{data.channelName}</Col>
          <Col span={12}>通道编码：{data.channelCode}</Col>
        </Row>
        <Row>
          <Col span={12}>调用代码：{data.channelWord}</Col>
          <Col span={12}>
            请求结果：
            {data.requestSuccess ? (
              <Tag color="success">请求成功</Tag>
            ) : (
              <Tag color="error">请求失败</Tag>
            )}
          </Col>
        </Row>
        <Row>
          <Col span={24}>请求地址：{data.requestUrl}</Col>
        </Row>
        <Row>
          <Col span={12}>请求耗时：{data.runTime}</Col>
          <Col span={12}>
            HTTP状态码：
            {!isNaN(data.httpCode as number) && (
              <Tag color={data.httpCode === 200 ? 'success' : 'error'}>{data.httpCode}</Tag>
            )}
          </Col>
        </Row>
        <Row>
          <Col span={24}>
            错误信息：
            <span className={`error ${styles.itemContent}`}>{data.errMsg}</span>
          </Col>
        </Row>
        <Row>
          <Col span={24}>
            请求参数：
            <Text copyable={!!data.params ? { text: data.params } : false} />
          </Col>
          <CodeMirror
            className={styles.codeMirror}
            value={formatJSON(data.params || '')}
            options={{
              mode: 'application/json',
              theme: 'idea',
              lineNumbers: true,
            }}
            onBeforeChange={() => {}}
          />
        </Row>
        <Row>
          <Col span={12}>
            响应结果：
            <Text copyable={!!data.result ? { text: data.result } : false} />
          </Col>
          <CodeMirror
            className={styles.codeMirror}
            value={formatJSON(data.result || '')}
            options={{
              mode: 'application/json',
              theme: 'idea',
              lineNumbers: true,
            }}
            onBeforeChange={() => {}}
          />
        </Row>
        <Row>
          <Col span={12}>
            请求头：
            <Text copyable={!!data.headers ? { text: data.headers } : false} />
          </Col>
          <CodeMirror
            className={styles.codeMirror}
            value={formatJSON(data.headers || '')}
            options={{
              mode: 'application/json',
              theme: 'idea',
              lineNumbers: true,
              CodeMirror: { height: '100px' },
            }}
            onBeforeChange={() => {}}
          />
        </Row>
      </div>
    </Spin>
  );
}

export default ChannelInfo;
