import { useRequest } from 'umi';
import { getChannelNotifyLog } from '@/services/merchant/transfer';
import { Badge, Col, Row, Spin, Steps, Tag } from 'antd';
import 'codemirror/lib/codemirror';
import 'codemirror/lib/codemirror.css';
import 'codemirror/mode/javascript/javascript'; // js
import 'codemirror/theme/idea.css';
import { Controlled as CodeMirror } from 'react-codemirror2';
import { STATUS_MAP } from '@/pages/product/notify/components/NotifyPayment';
import Ip from '@/components/IP';
import Copy from '@/components/Copy';
import { formatJSON } from '@/utils';
import styles from '../style.less';

interface IProps {
  serialOrderNo: string;
}

const { Step } = Steps;

const STEP_STATUS_MAP = {
  success: 'finish',
  fail: 'error',
  error: 'error',
};

const STEP_TITLE_MAP = {
  success: '回调成功',
  fail: '回调失败',
  error: '回调异常',
};

function ChannelNotify({ serialOrderNo }: IProps) {
  const { data = [], loading } = useRequest<{
    data: API.NotifyItem[];
  }>(getChannelNotifyLog.bind(null, serialOrderNo));

  return (
    <Spin spinning={loading}>
      <div className={styles.info}>
        {!!data.length && (
          <Steps direction="vertical">
            {data.map((item) => {
              const description = (
                <div>
                  <Row>
                    <Col span={12}>通道名称：{item.channelName}</Col>
                    <Col span={12}>通道编码：{item.channelCode}</Col>
                  </Row>
                  <Row>
                    <Col span={24}>
                      回调地址：
                      {item.method && <Tag color="processing">{item.method}</Tag>}
                      {item.uri}
                    </Col>
                  </Row>
                  <Row>
                    <Col span={12}>请求耗时：{item.runTime}</Col>
                    <Col span={12}>
                      处理状态：
                      {!!item.status && (
                        <Badge
                          status={STATUS_MAP[item.status]?.status}
                          text={STATUS_MAP[item.status]?.text}
                        />
                      )}
                    </Col>
                  </Row>
                  <Row>
                    <Col span={12}>
                      回调IP：
                      <Ip ip={item.ip} />
                    </Col>
                    <Col span={12}>回调时间：{item.notifyTime}</Col>
                  </Row>
                  <Row>
                    <Col span={24}>回调参数：{item.params && <Copy text={item.params} />}</Col>
                    <CodeMirror
                      className={styles.codeMirror}
                      value={formatJSON(item.params || '')}
                      options={{
                        mode: 'application/json',
                        theme: 'idea',
                        lineNumbers: true,
                      }}
                      onBeforeChange={() => {}}
                    />
                  </Row>
                  <Row>
                    <Col span={12}>请求头：{item.headers && <Copy text={item.headers} />}</Col>
                    <CodeMirror
                      className={styles.codeMirror}
                      value={formatJSON(item.headers || '')}
                      options={{
                        mode: 'application/json',
                        theme: 'idea',
                        lineNumbers: true,
                        CodeMirror: { height: '100px' },
                      }}
                      onBeforeChange={() => {}}
                    />
                  </Row>
                  <Row>
                    <Col span={12}>回调响应：{item.response}</Col>
                  </Row>
                </div>
              );
              const status = item?.status ? STEP_STATUS_MAP[item.status] : '';
              const title = item?.status ? STEP_TITLE_MAP[item.status] : '';
              return <Step status={status} title={title} description={description} />;
            })}
          </Steps>
        )}
      </div>
    </Spin>
  );
}

export default ChannelNotify;
