import { useEffect, useState } from 'react';
import { getPaymentDetail } from '@/services/merchant/transfer';
import { Badge, Col, Divider, Row, Spin, Typography } from 'antd';
import { PAYMENT_NOTIFY_STATUS_MAP } from '../constants';
import Ip from '@/components/IP';
import styles from '../style.less';

const { Text } = Typography;

interface IProps {
  serialOrderNo: string;
}

const AUDIT_STATUS = {
  true: <Badge status="success" text="已审计" />,
  false: <Badge status="error" text="未审计" />,
  null: null,
  undefined: null,
};

function Info({ serialOrderNo }: IProps) {
  const [loading, setLoading] = useState<any>(false);
  const [data, setData] = useState<Partial<API.PaymentOrderItem>>({});
  useEffect(() => {
    const init = async () => {
      setLoading(true);
      const res = await getPaymentDetail(serialOrderNo);
      setLoading(false);
      if (res?.code === '0000') {
        setData(res.data);
      }
    };
    if (serialOrderNo) {
      init();
    }
  }, [serialOrderNo]);

  return (
    <Spin spinning={loading}>
      <div className={styles.info}>
        <h3>商户</h3>
        <Row>
          <Col span={12}>商户ID：{data.mchId}</Col>
          <Col span={12}>商户名称：{data.mchName}</Col>
        </Row>
        <Row>
          <Col span={24}>
            商户交易号：
            <Text copyable={!!data.mchOrderNo}>{data.mchOrderNo}</Text>
          </Col>
        </Row>
        <Row>
          <Col span={12}>商户用户ID：{data.mchUserId}</Col>
          <Col span={12}>
            商户用户IP：
            <Ip ip={data.mchUserIp} />
          </Col>
        </Row>
        <Row>
          <Col span={12}>收款姓名：{data.accountName}</Col>
          <Col span={12}>预留手机号：{data.mobile}</Col>
        </Row>
        <Row>
          <Col span={12}>收款账号：{data.accountNumber}</Col>
          <Col span={12}>
            收款银行：{data.bankName}/{data.bankCode}
          </Col>
        </Row>
        <Row>
          <Col span={24}>开户支行：{data.subBank}</Col>
        </Row>
        <Row>
          <Col span={12}>用户邮箱：{data.email}</Col>
        </Row>
        <Row>
          <Col span={24}>
            回调状态：
            {!!data.notifyStatusCode && PAYMENT_NOTIFY_STATUS_MAP[data.notifyStatusCode] && (
              <Badge
                status={PAYMENT_NOTIFY_STATUS_MAP[data.notifyStatusCode].status}
                text={PAYMENT_NOTIFY_STATUS_MAP[data.notifyStatusCode].text}
              />
            )}
          </Col>
        </Row>
        <Row>
          <Col span={24}>回调地址：{data.notifyUrl}</Col>
        </Row>
        <Row>
          <Col span={24}>回调透传：{data.notifyAttach}</Col>
        </Row>
        <Row>
          <Col span={24}>订单备注：{data.remark}</Col>
        </Row>
        <Divider />
        <h3>通道</h3>
        <Row>
          <Col span={12}>大通道名称：{data.productName}</Col>
          <Col span={12}>大通道编码：{data.productCode}</Col>
        </Row>
        <Row>
          <Col span={12}>子通道名称：{data.channelName}</Col>
          <Col span={12}>子通道编码：{data.channelCode}</Col>
        </Row>
        {/* <Row>
          <Col span={24}>
            支付链接：
            {data.payUrl && (
              <Space>
                <span>{data.payUrl}</span>
                <Popover
                  trigger="click"
                  content={<img src={data.payUrlQrcode} className="qrcode-img" />}
                >
                  <a>查看二维码</a>
                </Popover>
              </Space>
            )}
          </Col>
        </Row> */}
        <Row>
          <Col span={24}>
            通道订单号：
            <Text copyable={!!data.channelOrderNo}>{data.channelOrderNo}</Text>
          </Col>
        </Row>
        <Row>
          <Col span={12}>通道费率：{data.channelFeeRate}</Col>
          <Col span={12}>通道方成本：{data.channelIncome}</Col>
        </Row>
        <Row>
          <Col span={24}>
            错误信息：
            <span className={`error ${styles.itemContent}`}>{data.message}</span>
          </Col>
        </Row>
        <Divider />
        <h3>审计</h3>
        <Row>
          <Col span={12}>订单金额：{data.amount}</Col>
          <Col span={12}>打款金额：{data.realAmount}</Col>
        </Row>
        <Row>
          <Col span={12}>商户费率：{data.mchFeeRate}</Col>
          <Col span={12}>商户手续费：{data.mchFee}</Col>
        </Row>
        <Row>
          <Col span={12}>代理费率：{data.proxyFeeRate}</Col>
          <Col span={12}>代理方分成：{data.proxyIncome}</Col>
        </Row>
        <Row>
          <Col span={12}>通道费率：{data.channelFeeRate}</Col>
          <Col span={12}>通道方成本：{data.channelIncome}</Col>
        </Row>
        <Row>
          <Col span={12}>商户扣款：{data.mchIncome}</Col>
          <Col span={12}>平台利润：{data.serialIncome}</Col>
        </Row>
        <Row>
          <Col span={24}>
            平台流水号：
            <Text copyable={!!data.serialOrderNo}>{data.serialOrderNo}</Text>
          </Col>
        </Row>
        <Row>
          <Col span={12}>创建时间：{data.createTime}</Col>
          <Col span={12}>创建耗时：{data.createRunTime}</Col>
        </Row>
        <Row>
          <Col span={12}>打款时间：{data.payTime}</Col>
          <Col span={12}>打款耗时：{data.payRunTime}</Col>
        </Row>
        <Row>
          <Col span={12}>结束时间：{data.finishTime}</Col>
          <Col span={12}>审计状态：{AUDIT_STATUS[`${data.audit}`]}</Col>
        </Row>
      </div>
    </Spin>
  );
}

export default Info;
