import { useRef } from 'react';
import ProForm, { ModalForm, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { replenishmentPaymentBatch } from '@/services/merchant/transfer';

interface IProps {
  serialOrderNos: (string | number)[];
  refresh: any;
}

const formItemLayout = {
  labelCol: {
    style: {
      width: '120px',
    },
  },
};

function ModalFormBatchReplenishment({ serialOrderNos, refresh }: IProps) {
  const formRef = useRef<ProFormInstance>();
  const refreshNew = () => {
    refresh();
    formRef.current?.setFieldsValue({ payPwd: '' });
  };

  return (
    <ModalForm
      {...formItemLayout}
      title="确认批量补单"
      width={500}
      formRef={formRef}
      layout="horizontal"
      onFinish={replenishmentPaymentBatch.bind(null, refreshNew, {
        serialOrderNos,
      })}
      initialValues={{ serialOrderNos }}
      modalProps={{
        onCancel: () => formRef.current?.setFieldsValue({ payPwd: '' }),
      }}
      trigger={<a>批量补单</a>}
    >
      <ProForm.Item style={{ marginBottom: 10 }} label="订单个数">
        {serialOrderNos.length}
      </ProForm.Item>
      <ProFormText.Password
        width={330}
        name="loginPwd"
        label="登录密码"
        placeholder="请输入登录密码"
        rules={[
          {
            required: true,
            validator: (_: any, value: string) => {
              if (!value) {
                return Promise.reject(new Error('请输入登录密码!'));
              }
              if (value.length < 4 || value.length > 20) {
                return Promise.reject(new Error('4-20位字符'));
              }
              return Promise.resolve();
            },
          },
        ]}
      />
    </ModalForm>
  );
}

export default ModalFormBatchReplenishment;
