import { useRef } from 'react';
import { Button } from 'antd';
import ProForm, { ModalForm, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { replenishmentPayment } from '@/services/merchant/transfer';

interface IProps {
  data: API.PaymentItem;
  refresh: any;
}

const formItemLayout = {
  labelCol: {
    style: {
      width: '110px',
    },
  },
};

function ModalFormReplenishment({ data, refresh }: IProps) {
  const formRef = useRef<ProFormInstance>();
  const refreshNew = () => {
    refresh();
    formRef.current?.setFieldsValue({ payPwd: '' });
  };

  return (
    <ModalForm
      {...formItemLayout}
      title="确认补单"
      width={500}
      formRef={formRef}
      layout="horizontal"
      onFinish={replenishmentPayment.bind(null, refreshNew)}
      initialValues={data}
      modalProps={{
        onCancel: () => formRef.current?.setFieldsValue({ payPwd: '' }),
      }}
      trigger={
        <Button type="link" size="small">
          补单
        </Button>
      }
    >
      <ProForm.Item style={{ marginBottom: 10 }} label="订单金额">
        {data.amount}
      </ProForm.Item>
      <ProForm.Item style={{ marginBottom: 10 }} label="商户交易号">
        {data.mchOrderNo}
      </ProForm.Item>
      <ProForm.Item style={{ marginBottom: 10 }} label="平台流水号">
        {data.serialOrderNo}
      </ProForm.Item>
      <ProForm.Item style={{ marginBottom: 10 }} label="通道订单号">
        {data.channelOrderNo}
      </ProForm.Item>
      <ProForm.Item name="serialOrderNo" noStyle>
        <input type="hidden" />
      </ProForm.Item>
      <ProFormText.Password
        width={330}
        name="loginPwd"
        label="登录密码"
        placeholder="请输入登录密码"
        rules={[
          {
            required: true,
            validator: (_: any, value: string) => {
              if (!value) {
                return Promise.reject(new Error('请输入登录密码!'));
              }
              if (value.length < 4 || value.length > 20) {
                return Promise.reject(new Error('4-20位字符'));
              }
              return Promise.resolve();
            },
          },
        ]}
      />
    </ModalForm>
  );
}

export default ModalFormReplenishment;
