import { Badge, Col, Row, Tag } from 'antd';
import 'codemirror/lib/codemirror';
import 'codemirror/lib/codemirror.css';
import 'codemirror/mode/javascript/javascript'; // js
import 'codemirror/theme/idea.css';
import { Controlled as CodeMirror } from 'react-codemirror2';
import { formatJSON } from '@/utils';
import Ip from '@/components/IP';
import styles from '../style.less';
import { STATUS_MAP } from './NotifyPayment';
import Copy from '@/components/Copy';

interface IProps {
  data: Partial<API.NotifyItem>;
}
function ChannelInfo({ data }: IProps) {
  console.log('data: ', data);

  return (
    <div className={styles.info}>
      <Row>
        <Col span={12}>通道名称：{data.channelName}</Col>
        <Col span={12}>通道编码：{data.channelCode}</Col>
      </Row>
      <Row>
        <Col span={24}>
          回调地址：
          {data.method && <Tag color="processing">{data.method}</Tag>}
          {data.uri}
        </Col>
      </Row>
      <Row>
        <Col span={12}>请求耗时：{data.runTime}</Col>
        <Col span={12}>
          处理状态：
          {!!data.status && (
            <Badge status={STATUS_MAP[data.status]?.status} text={STATUS_MAP[data.status]?.text} />
          )}
        </Col>
      </Row>
      <Row>
        <Col span={12}>
          回调IP：
          <Ip ip={data.ip} />
        </Col>
        <Col span={12}>回调时间：{data.notifyTime}</Col>
      </Row>
      <Row>
        <Col span={24}>回调参数：{data.params && <Copy text={data.params} />}</Col>
        <CodeMirror
          className={styles.codeMirror}
          value={formatJSON(data.params || '')}
          options={{
            mode: 'application/json',
            theme: 'idea',
            lineNumbers: true,
          }}
          onBeforeChange={() => {}}
        />
      </Row>
      <Row>
        <Col span={12}>请求头：{data.headers && <Copy text={data.headers} />}</Col>
        <CodeMirror
          className={styles.codeMirror}
          value={formatJSON(data.headers || '')}
          options={{
            mode: 'application/json',
            theme: 'idea',
            lineNumbers: true,
            CodeMirror: { height: '100px' },
          }}
          onBeforeChange={() => {}}
        />
      </Row>
      <Row>
        <Col span={12}>回调响应：{data.response}</Col>
      </Row>
    </div>
  );
}

export default ChannelInfo;
