import { useRef, useState } from 'react';
import ProTable from '@ant-design/pro-table';
import type { ProColumns, ActionType } from '@ant-design/pro-table';
import { PROTABLE_DEFAULT_SETTING } from '@/constants';
import { requestPaymentNotifyList } from '@/services/product/notify';
import Ip from '@/components/IP';
import { requestChannelOptions } from '@/services/merchant/payment';
import { Drawer } from 'antd';
import ChannelInfo from './ChannelInfo';

export const STATUS_MAP = {
  success: {
    text: '成功',
    status: 'success',
  },
  fail: {
    text: '失败',
    status: 'warning',
  },
  error: {
    text: '异常',
    status: 'error',
  },
};

function NotifyPayment() {
  const actionRef = useRef<ActionType>();

  // 通道调用信息
  const [channelVisible, setChannelVisible] = useState<boolean>(false);
  const [curData, setCurData] = useState<Partial<API.NotifyItem>>({});

  const showChannelInfo = (record: API.NotifyItem) => {
    setCurData(record);
    setChannelVisible(true);
  };

  const columns: ProColumns<API.NotifyItem>[] = [
    {
      title: '通道',
      order: 9,
      key: 'channelIdPayment',
      dataIndex: 'channelIdPayment',
      hideInTable: true,
      valueType: 'select',
      request: requestChannelOptions,
      fieldProps: {
        showSearch: true,
      },
    },
    {
      title: '通道ID',
      width: 65,
      dataIndex: 'channelId',
      search: false,
    },
    {
      title: '通道标识',
      search: false,
      width: 140,
      dataIndex: 'channelCode',
    },
    {
      title: '通道名称',
      search: false,
      ellipsis: true,
      width: 135,
      dataIndex: 'channelName',
    },
    {
      title: '回调IP',
      width: 138,
      dataIndex: 'notifyIp',
      render: (_, record) => <Ip ip={record.ip} />,
    },
    {
      title: '处理状态',
      dataIndex: 'status',
      width: 80,
      valueType: 'select',
      valueEnum: STATUS_MAP,
    },
    {
      title: '回调地址',
      width: 290,
      search: false,
      ellipsis: true,
      dataIndex: 'uri',
    },
    {
      title: '回调参数',
      width: 430,
      ellipsis: true,
      dataIndex: 'params',
    },
    {
      title: '回调响应',
      width: 200,
      search: false,
      ellipsis: true,
      dataIndex: 'response',
    },
    {
      title: '平台流水号',
      width: 330,
      order: 6,
      dataIndex: 'serialOrderNo',
      ellipsis: true,
      copyable: true,
    },
    {
      title: '回调时间',
      width: 135,
      search: false,
      fixed: 'right',
      dataIndex: 'notifyTime',
    },
    {
      title: '操作',
      search: false,
      fixed: 'right',
      width: 70,
      render: (_, record) => (
        <div>
          <a onClick={showChannelInfo.bind(null, record)}>详情</a>
        </div>
      ),
    },
  ];
  return (
    <div>
      <ProTable
        {...PROTABLE_DEFAULT_SETTING}
        scroll={{ x: 1450, y: 'calc(100vh - 280px)' }}
        columns={columns}
        request={requestPaymentNotifyList}
        actionRef={actionRef}
      />

      <Drawer
        destroyOnClose
        width={700}
        visible={channelVisible}
        title="通道回调信息"
        onClose={() => setChannelVisible(false)}
      >
        <ChannelInfo data={curData} />
      </Drawer>
    </div>
  );
}

export default NotifyPayment;
