import { useState } from 'react';
import { history } from 'umi';
import { Tabs } from 'antd';
import { ROUTER_ENUM } from '@/constants';
import NotifyPayment from './components/NotifyPayment';
import NotifyTransfer from './components/NotifyTransfer';
import styles from './style.less';

const { TabPane } = Tabs;
const TAB_KEY = {
  PAYMENT: '1',
  TRANSFER: '2',
};

function Notify({ location: { query } }: any) {
  const [activeKey, setActiveKey] = useState<string>(query.tabKey || TAB_KEY.PAYMENT);
  const handleTabChange = (tabKey: string) => {
    setActiveKey(tabKey);
    history.replace({
      pathname: ROUTER_ENUM.productNotify,
      query: {
        ...query,
        tabKey,
      },
    });
  };

  return (
    <div className={styles.container}>
      <Tabs activeKey={activeKey} onChange={handleTabChange} className={styles.container}>
        <TabPane tab="支付通道" key={TAB_KEY.PAYMENT}>
          {activeKey === TAB_KEY.PAYMENT && <NotifyPayment />}
        </TabPane>
        <TabPane tab="代付通道" key={TAB_KEY.TRANSFER}>
          {activeKey === TAB_KEY.TRANSFER && <NotifyTransfer />}
        </TabPane>
      </Tabs>
    </div>
  );
}

export default Notify;
