import { PRODUCT_ICON_ENUM, PROTABLE_DEFAULT_SETTING } from '@/constants';
import ProTable from '@ant-design/pro-table';
import type { ActionType } from '@ant-design/pro-table';
import type { ProColumns } from '@ant-design/pro-table';
import { Avatar, message, Popconfirm, Space, Switch, Tag } from 'antd';
import { useRef } from 'react';
// import ModalFormEdit from './ModalFormEdit';
import {
  deletePaymentProduct,
  requestPaymentProductList,
  switchPaymentProductStatus,
} from '@/services/product/payment';
import ModalFormCopy from './ModalFormCopy';
import { PAYMENT_TYPE_ENUM } from '../../constants';
import { formatAmountLimit } from '@/utils';

const copyData = (record: API.PaymentProductItem) => {
  const d = { ...record };
  d.productName = d.productName ? `${d.productName}-cp` : '';
  d.productCode = d.productCode ? `${d.productCode}-cp` : '';
  return d;
};

const PRODUCT_TYPE = {
  H5: <Tag color="success">H5</Tag>,
  SDK: <Tag color="processing">SDK</Tag>,
};

function ChannelLarge() {
  const actionRef = useRef<ActionType>();

  const handleDelete = async (id: string) => {
    const res = await deletePaymentProduct(id);
    if (res?.code === '0000') {
      actionRef.current?.reload();
      message.success('删除成功');
    }
  };

  // 切换状态
  const switchStatus = async (id: string, status: number) => {
    const text = status === 0 ? '禁用' : '启用';
    const res = await switchPaymentProductStatus(id, status);
    if (res?.code === '0000') {
      actionRef.current?.reload?.();
      message.success(`${text}成功`);
    }
  };

  const columns: ProColumns<API.PaymentProductItem>[] = [
    {
      title: '通道ID',
      dataIndex: 'id',
      width: 65,
    },
    {
      title: '分组名称',
      width: 100,
      dataIndex: 'groupName',
    },
    {
      title: '通道名称',
      width: 150,
      dataIndex: 'productName',
      render: (productName, record) => (
        <Space>
          <Avatar src={PRODUCT_ICON_ENUM[record.payMethod]} shape="square" size="small" />
          <span>{record.productName}</span>
        </Space>
      ),
    },
    {
      title: '通道编码',
      width: 120,
      copyable: true,
      dataIndex: 'productCode',
    },
    {
      title: '通道类型',
      width: 80,
      search: false,
      dataIndex: 'productType',
      render: (_, record) => PRODUCT_TYPE[record.productType || ''],
    },
    {
      title: '币种',
      width: 65,
      search: false,
      dataIndex: 'currency',
    },
    {
      title: '单笔限额',
      width: 180,
      ellipsis: true,
      search: false,
      dataIndex: 'amountLimit',
      render: (_, record) => formatAmountLimit(record.amountLimit || ''),
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: 80,
      render: (_, record) => {
        const { status } = record;
        return (
          <Switch
            // disabled={!googleStatus}
            checkedChildren="启用"
            unCheckedChildren="禁用"
            checked={!!status}
            onClick={switchStatus.bind(null, record.id as string, status === 0 ? 1 : 0)}
          />
        );
      },
      valueType: 'select',
      valueEnum: {
        0: {
          text: '禁用',
        },
        1: {
          text: '启用',
        },
      },
    },
    {
      title: '创建时间',
      width: 135,
      search: false,
      dataIndex: 'createTime',
    },

    {
      title: '操作',
      search: false,
      width: 100,
      fixed: 'right',
      render: (_, record) => (
        <Space>
          {/* <ModalFormEdit
            refresh={actionRef.current?.reset}
            initialData={record}
            type={PAYMENT_TYPE_ENUM.PRODUCT}
          /> */}
          <ModalFormCopy
            refresh={actionRef.current?.reset}
            initialData={copyData(record)}
            type={PAYMENT_TYPE_ENUM.PRODUCT}
          />
          <Popconfirm title="确定删除该商户账号？" onConfirm={handleDelete.bind(null, record.id)}>
            <a>删除</a>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <ProTable
      {...PROTABLE_DEFAULT_SETTING}
      scroll={{ x: 1150, y: 'calc(100vh - 340px)' }}
      columns={columns}
      request={requestPaymentProductList}
      form={{
        colon: false,
      }}
      actionRef={actionRef}
      search={{
        labelWidth: 'auto',
      }}
      defaultSize="small"
    />
  );
}

export default ChannelLarge;
