import { useRequest } from 'umi';
import { Spin, Tabs } from 'antd';
import FormCommon from './FormCommon';
import FormFormalParams from './FormFormalParams';
import FormInvokeResolve from './FormInvokeResolve';
import FormNotifyResolve from './FormNotifyResolve';
import FormParams from './FormParams';
import FormQueryParams from './FormQueryParams';
import { getChannelDetail } from '@/services/product/payment';

interface IProps {
  data: API.MerchantChannelItem;
  onCancel: () => void;
  refresh: any;
}

const { TabPane } = Tabs;
const TAB_ENUM = {
  COMMON: 'common',
  PARAMS: 'params',
  FORMAL_PARAMS: 'formalParams',
  INVOKE_RESOLVE: 'invokeResolve',
  NOTIFY_RESOLVE: 'notifyResolve',
  QUERY: 'query',
};
const TAB_MAP = {
  [TAB_ENUM.COMMON]: '常规',
  [TAB_ENUM.PARAMS]: '参数',
  [TAB_ENUM.FORMAL_PARAMS]: '形参',
  [TAB_ENUM.INVOKE_RESOLVE]: '自动解析',
  [TAB_ENUM.NOTIFY_RESOLVE]: '回调解析',
  [TAB_ENUM.QUERY]: '订单查询',
};

function ChannelSubEdit({ data: record, onCancel, refresh }: IProps) {
  const { data, loading } = useRequest(getChannelDetail.bind(null, record.id));
  console.log('data: ', data);

  return (
    <Spin spinning={loading}>
      <Tabs>
        <TabPane tab={TAB_MAP[TAB_ENUM.COMMON]} key={TAB_ENUM.COMMON}>
          {data && <FormCommon data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.PARAMS]} key={TAB_ENUM.PARAMS}>
          {data && <FormParams data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.FORMAL_PARAMS]} key={TAB_ENUM.FORMAL_PARAMS}>
          {data && <FormFormalParams data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.INVOKE_RESOLVE]} key={TAB_ENUM.INVOKE_RESOLVE}>
          {data && <FormInvokeResolve data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.NOTIFY_RESOLVE]} key={TAB_ENUM.NOTIFY_RESOLVE}>
          {data && <FormNotifyResolve data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
        <TabPane tab={TAB_MAP[TAB_ENUM.QUERY]} key={TAB_ENUM.QUERY}>
          {data && <FormQueryParams data={data} onCancel={onCancel} refresh={refresh} />}
        </TabPane>
      </Tabs>
    </Spin>
  );
}

export default ChannelSubEdit;
