import { editFormalParam } from '@/services/product/payment';
import ProForm, { ProFormText } from '@ant-design/pro-form';
import { Button, Col, message, Row, Space } from 'antd';

interface IProps {
  data: API.MerchantChannelItem;
  onCancel: () => void;
  refresh: () => void;
}

const formItemLayout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};
function FormFormalParams({ data, onCancel, refresh }: IProps) {
  const handleFinish = async (values: any) => {
    const params = { id: data.id, ...values };
    const res = await editFormalParam(params);
    if (res.code === '0000') {
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ProForm
        {...formItemLayout}
        layout="horizontal"
        initialValues={data}
        onFinish={handleFinish}
        submitter={{
          searchConfig: { submitText: '确认' },
          render: (props, doms) => {
            return (
              <Space style={{ width: '100%', justifyContent: 'flex-end' }}>
                <Button onClick={onCancel}>取消</Button>
                {doms[1]}
              </Space>
            );
          },
        }}
        // onReset={handleReset}
      >
        <Row>
          <Col span={11}>
            <ProFormText name="channelKeyMerchantNo" placeholder="请输入商户ID" label="商户ID" />
          </Col>
          <Col span={11}>
            <ProFormText name="channelKeyAppKey" placeholder="请输入应用ID" label="应用ID" />
          </Col>
        </Row>
        <Row>
          <Col span={11}>
            <ProFormText name="channelKeyUserId" placeholder="请输入用户ID" label="用户ID" />
          </Col>
          <Col span={11}>
            <ProFormText name="channelKeyUserIp" placeholder="请输入用户IP" label="用户IP" />
          </Col>
        </Row>
        <Row>
          <Col span={11}>
            <ProFormText
              name="channelKeySerialOrderNo"
              placeholder="请输入平台流水号"
              label="平台流水号"
            />
          </Col>
          <Col span={11}>
            <ProFormText name="channelKeyAmount" placeholder="请输入订单金额" label="订单金额" />
          </Col>
        </Row>
        <Row>
          <Col span={11}>
            <ProFormText
              name="channelKeyTimestamp"
              placeholder="请输入毫秒时间戳"
              label="毫秒时间戳"
            />
          </Col>
          <Col span={11}>
            <ProFormText
              name="channelKeyYmdhms"
              placeholder="请输入格式化时间"
              label="格式化时间"
            />
          </Col>
        </Row>
        <Row>
          <Col span={11}>
            <ProFormText name="channelKeyNotifyUrl" placeholder="请输入回调地址" label="回调地址" />
          </Col>
          <Col span={11}>
            <ProFormText name="channelKeyReturnUrl" placeholder="请输入跳转地址" label="跳转地址" />
          </Col>
        </Row>
        <Row>
          <Col span={11}>
            <ProFormText name="channelKeyUserName" placeholder="请输入用户姓名" label="用户姓名" />
          </Col>
          <Col span={11}>
            <ProFormText
              name="channelKeyMobile"
              placeholder="请输入用户手机号"
              label="用户手机号"
            />
          </Col>
        </Row>
        <Row>
          <Col span={11}>
            <ProFormText name="channelKeyEmail" placeholder="请输入用户邮箱" label="用户邮箱" />
          </Col>
          <Col span={11}>
            <ProFormText name="channelKeySign" placeholder="请输入参数签名" label="参数签名" />
          </Col>
        </Row>
      </ProForm>
    </div>
  );
}

export default FormFormalParams;
