import { editInvokeResolve } from '@/services/product/payment';
import ProForm, { ProFormText } from '@ant-design/pro-form';
import { Button, message, Space } from 'antd';

interface IProps {
  data: API.MerchantChannelItem;
  onCancel: () => void;
  refresh: () => void;
}

const formItemLayout = {
  labelCol: {
    span: 4,
  },
  wrapperCol: {
    span: 18,
  },
};

function FormInvokeResolve({ data, onCancel, refresh }: IProps) {
  const handleFinish = async (values: any) => {
    const params = { id: data.id, ...values };
    const res = await editInvokeResolve(params);
    if (res.code === '0000') {
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ProForm
        {...formItemLayout}
        layout="horizontal"
        initialValues={data}
        onFinish={handleFinish}
        submitter={{
          searchConfig: { submitText: '确认' },
          render: (props, doms) => {
            return (
              <Space style={{ width: '100%', justifyContent: 'flex-end' }}>
                <Button onClick={onCancel}>取消</Button>
                {doms[1]}
              </Space>
            );
          },
        }}
        // onReset={handleReset}
      >
        <ProFormText
          name="resultSuccessFlag"
          label="成功标记"
          placeholder="请输入成功标记"
          rules={[{ required: true, message: '请输入成功标记！' }]}
        />
        <ProFormText
          name="resultErrorMsg"
          label="失败信息"
          placeholder="请输入失败信息"
          rules={[{ required: true, message: '请输入失败信息！' }]}
        />
        <ProFormText
          name="resultPayUrl"
          label="支付链接"
          placeholder="请输入支付链接"
          rules={[{ required: true, message: '请输入支付链接！' }]}
        />
        <ProFormText name="resultChannelNo" placeholder="请输入通道订单号" label="通道订单号" />
      </ProForm>
    </div>
  );
}

export default FormInvokeResolve;
