import InputArray from '@/components/InputArray';
import { editNotifyResolve } from '@/services/product/payment';
import ProForm, { ProFormRadio, ProFormSelect, ProFormText } from '@ant-design/pro-form';
import { Button, Col, message, Row, Space } from 'antd';
import { AMOUNT_SCALA_OPTIONS, HTTP_METHOD_ENNUM } from '../../constants';

interface IProps {
  data: API.MerchantChannelItem;
  onCancel: () => void;
  refresh: () => void;
}

const formItemLayout = {
  labelCol: {
    span: 4,
  },
  wrapperCol: {
    span: 18,
  },
};

const subFormItemLayout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 16,
  },
};

function FormNotifyResolve({ data, onCancel, refresh }: IProps) {
  const handleFinish = async (values: any) => {
    const params = { id: data.id, ...values };
    const res = await editNotifyResolve(params);
    if (res.code === '0000') {
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ProForm
        {...formItemLayout}
        layout="horizontal"
        initialValues={data}
        onFinish={handleFinish}
        submitter={{
          searchConfig: { submitText: '确认' },
          render: (props, doms) => {
            return (
              <Space style={{ width: '100%', justifyContent: 'flex-end' }}>
                <Button onClick={onCancel}>取消</Button>
                {doms[1]}
              </Space>
            );
          },
        }}
        // onReset={handleReset}
      >
        <Row>
          <Col span={12}>
            <ProFormSelect
              {...subFormItemLayout}
              name="notifyType"
              label="请求方式"
              placeholder="请选择请求方式"
              valueEnum={HTTP_METHOD_ENNUM}
              rules={[{ required: true, message: '请选择请求方式！' }]}
            />
          </Col>
          <Col span={12}>
            <ProFormRadio.Group
              {...subFormItemLayout}
              name="notifyAmountScala"
              label="金额单位"
              options={AMOUNT_SCALA_OPTIONS}
              placeholder="请选择金额单位"
              rules={[{ required: true, message: '请选择金额单位！' }]}
            />
          </Col>
        </Row>
        <ProForm.Item name="notifyIpArr" label="回调IP">
          <InputArray label="IP" />
        </ProForm.Item>
        <ProFormText
          name="notifySerialOrderNoKey"
          placeholder="请输入平台流水号"
          label="平台流水号"
        />
        <ProFormText name="notifyRealAmountKey" placeholder="请输入金额参数" label="金额参数" />
        <ProFormText name="notifySignKey" placeholder="请输入签名参数" label="签名参数" />
        <ProFormText name="notifyErrorMsg" label="失败信息" placeholder="请输入失败信息" />
        <ProFormText
          name="notifyPaySuccessFlag"
          placeholder="请输入支付成功标记"
          label="支付成功标记"
        />
        <ProFormText
          name="notifyPayFailFlag"
          placeholder="请输入支付失败标记"
          label="支付失败标记"
        />
        <ProFormText
          name="notifySuccessResponse"
          placeholder="请输入回调成功响应"
          label="回调成功响应"
        />
      </ProForm>
    </div>
  );
}

export default FormNotifyResolve;
