import ProForm, { ModalForm, ProFormDependency, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { message } from 'antd';
import { useRef } from 'react';
import { copyPaymentChannel, copyPaymentProduct } from '@/services/product/payment';
import { PAYMENT_TYPE_ENUM, PAYMENT_TYPE_MAP } from '../../constants';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  initialData: API.PaymentProductItem;
  refresh?: () => void | undefined;
  type?: string;
}

function ModalFormCopy({ initialData, refresh, type = PAYMENT_TYPE_ENUM.PRODUCT }: IProps) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: API.PaymentProductItem) => {
    const params = { ...initialData, ...values };
    let res = {} as API.RequestResult;
    if (type === PAYMENT_TYPE_ENUM.PRODUCT) {
      res = await copyPaymentProduct(params);
    } else if (type === PAYMENT_TYPE_ENUM.CHANNEL) {
      res = await copyPaymentChannel(params);
    }
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success('复制成功');
      return true;
    }
    return false;
  };

  return (
    <div>
      <ModalForm
        {...formItemLayout}
        formRef={formRef}
        title={`复制${PAYMENT_TYPE_MAP[type]}`}
        layout="horizontal"
        width={720}
        trigger={<a>复制</a>}
        onFinish={handleFinish}
        initialValues={initialData}
      >
        <ProForm.Item label="通道ID">
          <ProFormDependency name={['id']}>{({ id }) => <span>{id}</span>}</ProFormDependency>
        </ProForm.Item>
        {type === PAYMENT_TYPE_ENUM.CHANNEL && (
          <ProForm.Item label="调用代码">
            <ProFormDependency name={['channelWord']}>
              {({ channelWord }) => <span>{channelWord}</span>}
            </ProFormDependency>
          </ProForm.Item>
        )}
        <ProFormText
          name={`${type}Name`}
          placeholder="请输入通道名称"
          label="通道名称"
          width={500}
          rules={[{ required: true, message: '请输入通道名称!' }]}
        />
        <ProFormText
          name={`${type}Code`}
          placeholder="请输入通道编码"
          label="通道编码"
          width={500}
          rules={[{ required: true, message: '请输入通道编码!' }]}
        />
      </ModalForm>
    </div>
  );
}

export default ModalFormCopy;
