import { editQueryParam } from '@/services/product/transfer';
import ProForm, { ProFormRadio, ProFormSelect, ProFormText } from '@ant-design/pro-form';
import { Button, Col, message, Row, Space } from 'antd';
import { AMOUNT_SCALA_OPTIONS, HTTP_METHOD_ENNUM } from '../../constants';

interface IProps {
  data: API.MerchantChannelItem;
  onCancel: () => void;
  refresh: () => void;
}

const formItemLayout = {
  labelCol: {
    span: 8,
  },
  wrapperCol: {
    span: 14,
  },
};

function FormQueryParams({ data, onCancel, refresh }: IProps) {
  const handleFinish = async (values: any) => {
    const params = { id: data.id, ...values };
    const res = await editQueryParam(params);
    if (res.code === '0000') {
      refresh?.();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <ProForm
        {...formItemLayout}
        layout="horizontal"
        initialValues={data}
        onFinish={handleFinish}
        submitter={{
          searchConfig: { submitText: '确认' },
          render: (props, doms) => {
            return (
              <Space style={{ width: '100%', justifyContent: 'flex-end' }}>
                <Button onClick={onCancel}>取消</Button>
                {doms[1]}
              </Space>
            );
          },
        }}
        // onReset={handleReset}
      >
        <Row>
          <Col span={12}>
            <ProFormSelect
              name="queryHttpMethod"
              label="请求方式"
              valueEnum={HTTP_METHOD_ENNUM}
              rules={[{ required: true, message: '请选择请求方式！' }]}
            />
          </Col>
          <Col span={12}>
            <ProFormRadio.Group
              name="queryAmountScala"
              label="金额单位"
              options={AMOUNT_SCALA_OPTIONS}
              rules={[{ required: true, message: '请选择金额单位！' }]}
            />
          </Col>
        </Row>
        <ProFormText
          labelCol={{ span: 4 }}
          wrapperCol={{ span: 18 }}
          name="queryGateWay"
          placeholder="请输入查询网关"
          label="查询网关"
        />
        <Row>
          <Col span={12}>
            <ProFormText name="queryKeyMerchantNo" placeholder="请输入商户ID" label="商户ID" />
          </Col>
          <Col span={11}>
            <ProFormText name="queryKeyAppKey" placeholder="请输入应用ID" label="应用ID" />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormText
              name="queryKeySerialOrderNo"
              placeholder="请输入平台流水号"
              label="平台流水号"
            />
          </Col>
          <Col span={11}>
            <ProFormText
              name="queryKeyChannelOrderNo"
              placeholder="请输入通道订单号"
              label="通道订单号"
            />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormText
              name="queryKeyTimestamp"
              placeholder="请输入毫秒时间戳"
              label="毫秒时间戳"
            />
          </Col>
          <Col span={11}>
            <ProFormText name="queryKeyYmdhms" placeholder="请输入格式化时间" label="格式化时间" />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormText name="queryKeySign" placeholder="请输入签名" label="签名" />
          </Col>
          <Col span={11}>
            <ProFormText name="queryErrorMsg" placeholder="请输入失败信息" label="失败信息" />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormText
              name="querySuccessFlag"
              placeholder="请输入查询成功标记"
              label="查询成功标记"
            />
          </Col>
          <Col span={11}>
            <ProFormText
              name="queryRealAmountKey"
              placeholder="请输入实际交易金额"
              label="实际交易金额"
            />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormText
              name="queryPaySuccessFlag"
              placeholder="请输入支付成功标记"
              label="支付成功标记"
            />
          </Col>
          <Col span={11}>
            <ProFormText
              name="queryPayFailFlag"
              placeholder="请输入支付失败标记"
              label="支付失败标记"
            />
          </Col>
        </Row>
        <Row>
          <Col span={12}>
            <ProFormText name="queryPayIngFlag" placeholder="请输入支付中标记" label="支付中标记" />
          </Col>
        </Row>
        <ProFormText
          labelCol={{ span: 4 }}
          wrapperCol={{ span: 18 }}
          name="queryExtension"
          placeholder="请输入查询扩展参数"
          label="查询扩展参数"
        />
      </ProForm>
    </div>
  );
}

export default FormQueryParams;
