import { PROTABLE_DEFAULT_SETTING } from '@/constants';
import ProTable from '@ant-design/pro-table';
import type { ProColumns } from '@ant-design/pro-table';
import { requestMerchantLog } from '@/services/setting';
import { requestMerchantOptions } from '@/services/commons';
import Ip from '@/components/IP';
import type { ProFormInstance } from '@ant-design/pro-form';
import { useEffect, useRef } from 'react';

const columns: ProColumns<API.LogItem>[] = [
  {
    title: '商户ID',
    search: false,
    width: 65,
    dataIndex: 'mchId',
  },
  {
    title: '商户',
    dataIndex: 'mchId',
    valueType: 'select',
    request: requestMerchantOptions,
    fieldProps: {
      showSearch: true,
    },
    hideInTable: true,
  },
  {
    title: '商户名称',
    width: 110,
    search: false,
    dataIndex: 'mchName',
  },
  {
    title: '登录账号',
    width: 100,
    dataIndex: 'loginName',
  },
  {
    title: '谷歌验证码',
    width: 90,
    search: false,
    dataIndex: 'googleCode',
  },
  {
    title: '登录IP',
    width: 140,
    dataIndex: 'loginIp',
    render: (ip) => <Ip ip={ip as string} />,
  },
  {
    title: '浏览器信息',
    search: false,
    dataIndex: 'userAgent',
    ellipsis: true,
  },
  {
    title: '登录时间',
    width: 140,
    search: false,
    dataIndex: 'loginTime',
  },
  {
    title: '登录结果',
    width: 75,
    dataIndex: 'success',
    valueType: 'select',
    valueEnum: {
      true: {
        text: '成功',
        status: 'Success',
      },
      false: {
        text: '失败',
        status: 'Error',
      },
    },
  },
  {
    title: '说明',
    width: 180,
    search: false,
    dataIndex: 'message',
  },
];
function LoginRecordChannel({ location: { query } }: any) {
  const formRef = useRef<ProFormInstance>();

  useEffect(() => {
    if (query.loginIp) {
      formRef.current?.setFieldsValue({ loginIp: query.loginIp });
      formRef.current?.submit();
    }
  }, [query.loginIp]);

  return (
    <ProTable
      {...PROTABLE_DEFAULT_SETTING}
      scroll={{ x: 1100, y: 'calc(100vh - 180px)' }}
      formRef={formRef}
      columns={columns}
      request={requestMerchantLog}
      form={{
        colon: false,
      }}
      // actionRef={actionRef}
      defaultSize="small"
    />
  );
}

export default LoginRecordChannel;
