import { useRef } from 'react';
import { PlusOutlined } from '@ant-design/icons';
import { DrawerForm, ProFormDigit, ProFormText, ProFormTextArea } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { Button, message } from 'antd';
import { addBlackIP } from '@/services/setting';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  refresh?: () => void | undefined;
  type?: string;
  data?: any;
}

function ModalFormAdd({ refresh }: IProps) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: API.MerchantItem) => {
    const res = await addBlackIP({ ...values });
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`创建成功`);
      return true;
    }
    return false;
  };

  return (
    <div>
      <DrawerForm
        {...formItemLayout}
        formRef={formRef}
        title="创建黑名单IP"
        layout="horizontal"
        width={720}
        trigger={
          <Button icon={<PlusOutlined />} type="primary">
            创建黑名单IP
          </Button>
        }
        onFinish={handleFinish}
      >
        <ProFormText
          name="blackIp"
          placeholder="请输入黑名单IP"
          label="黑名单IP"
          fieldProps={{ maxLength: 15 }}
          width={500}
          rules={[{ required: true, message: '请输入黑名单IP!' }]}
        />
        <ProFormDigit
          name="validDay"
          label="有效期"
          placeholder="请输入有效期(1~7天)"
          min={1}
          max={7}
          rules={[{ required: true, message: '请输入有效期!' }]}
          fieldProps={{ addonAfter: '天' }}
          width={500}
        />
        <ProFormTextArea name="memo" label="备注" placeholder="请输入备注" width={500} />
      </DrawerForm>
    </div>
  );
}

export default ModalFormAdd;
