import { useRef } from 'react';
import { PROTABLE_DEFAULT_SETTING } from '@/constants';
import ProTable from '@ant-design/pro-table';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import Ip from '@/components/IP';
import { message, Popconfirm } from 'antd';
import { deleteBlackIP, requestBlackIP } from '@/services/setting';
import ModalFormAdd from './components/ModalFormAdd';

function BlackIP() {
  const actionRef = useRef<ActionType>();

  const handleDelete = async (id: string) => {
    const res = await deleteBlackIP(id);
    if (res?.code === '0000') {
      actionRef.current?.reload();
      message.success('删除成功');
    }
  };

  const columns: ProColumns<API.BlackIPItem>[] = [
    {
      title: 'ID',
      search: false,
      width: 65,
      dataIndex: 'id',
    },
    {
      title: '黑名单IP',
      width: 138,
      dataIndex: 'blackIp',
      render: (_, record) => <Ip ip={record.blackIp} />,
    },
    {
      title: '过期时间',
      width: 170,
      search: false,
      dataIndex: 'expireTime',
    },
    {
      title: '备注',
      search: false,
      dataIndex: 'memo',
    },
    {
      title: '创建时间',
      width: 140,
      search: false,
      dataIndex: 'createTime',
    },
    {
      title: '创建人',
      width: 100,
      search: false,
      dataIndex: 'createOperatorName',
    },
    {
      title: '操作',
      search: false,
      fixed: 'right',
      width: 90,
      render: (_, record) => (
        <Popconfirm title="确定删除该黑名单IP？" onConfirm={handleDelete.bind(null, record.id)}>
          <a>删除</a>
        </Popconfirm>
      ),
    },
  ];
  return (
    <ProTable
      {...PROTABLE_DEFAULT_SETTING}
      scroll={{ y: 'calc(100vh - 340px)' }}
      columns={columns}
      request={requestBlackIP}
      form={{
        colon: false,
      }}
      actionRef={actionRef}
      defaultSize="small"
      toolBarRender={() => [<ModalFormAdd refresh={actionRef.current?.reset} />]}
      rowClassName={(record) => ('expired' in record && record.expired ? 'row-disabled' : '')}
    />
  );
}

export default BlackIP;
