import ProList from '@ant-design/pro-list';
import { deleteSystemCache, requestSystemCache } from '@/services/setting';
import { message, Popconfirm } from 'antd';
import { useRef, useState } from 'react';
import type { ActionType } from '@ant-design/pro-table';
import CacheItem from './components/CacheItem';
import styles from './style.less';
import { copy } from '@/utils';

function Cache() {
  const actionRef = useRef<ActionType>();
  const [count, setCount] = useState<number>(0);

  const handleDelete = async (key: string) => {
    const res = await deleteSystemCache(key);
    if (res?.code === '0000') {
      actionRef.current?.reload();
      message.success('删除成功');
    }
  };
  return (
    <ProList
      className={styles.container}
      actionRef={actionRef as any}
      search={{ labelWidth: 'auto' }}
      onRow={(record: any) => {
        return {
          onMouseEnter: () => {
            console.log(record);
          },
          onClick: () => {
            console.log(record);
          },
        };
      }}
      rowKey="key"
      request={requestSystemCache.bind(null, setCount)}
      headerTitle={<span>缓存总数：{count}</span>}
      metas={{
        description: {
          dataIndex: 'title',
          search: false,
          render: (_, row) => {
            return <CacheItem data={row} />;
          },
        },
        actions: {
          render: (_, row) => [
            <a onClick={copy.bind(null, row.value)}>复制</a>,
            <Popconfirm title="确定删除？" onConfirm={handleDelete.bind(null, row.key)}>
              <a>删除</a>
            </Popconfirm>,
          ],
          search: false,
        },
        status: {
          title: 'KEY',
          dataIndex: 'key',
        },
      }}
    />
  );
}

export default Cache;
