import { useRef } from 'react';
import { DrawerForm, ProFormText, ProFormTextArea } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { message } from 'antd';
import { editSystemConfig } from '@/services/setting';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  refresh?: () => void | undefined;
  type?: string;
  data?: any;
}

function ModalFormAdd({ refresh, data }: IProps) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: API.SystemConfigItem) => {
    const res = await editSystemConfig({ ...data, ...values });
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`编辑成功`);
      return true;
    }
    return false;
  };

  const handleVisibleChange = (visible: boolean) => {
    if (visible) {
      formRef.current?.setFieldsValue({ ...data, status: !!data.status });
    }
  };

  return (
    <div>
      <DrawerForm
        {...formItemLayout}
        formRef={formRef}
        title="编辑字段"
        layout="horizontal"
        width={720}
        trigger={<a>编辑</a>}
        onFinish={handleFinish}
        onVisibleChange={handleVisibleChange}
        initialValues={data}
      >
        <ProFormText name="configCode" label="KEY" readonly required width={500} />
        <ProFormTextArea
          name="configValue"
          fieldProps={{ autoSize: { minRows: 10 } }}
          label="VALUE"
          width={500}
          rules={[{ required: true, message: '请输入VALUE!' }]}
        />
        <ProFormTextArea
          name="remark"
          label="备注"
          fieldProps={{ autoSize: { minRows: 10 } }}
          placeholder="请输入备注"
          width={500}
        />
      </DrawerForm>
    </div>
  );
}

export default ModalFormAdd;
