import { useRef } from 'react';
import { PROTABLE_DEFAULT_SETTING } from '@/constants';
import ProTable from '@ant-design/pro-table';
import type { ActionType, ProColumns } from '@ant-design/pro-table';
import { requestSystemConfig } from '@/services/setting';
import ModalFormEdit from './components/ModalFormEdit';

function Config() {
  const actionRef = useRef<ActionType>();
  const columns: ProColumns<API.BlackIPItem>[] = [
    {
      title: 'ID',
      search: false,
      width: 65,
      dataIndex: 'id',
    },
    {
      title: 'KEY',
      dataIndex: 'configCode',
    },
    {
      title: 'VALUE',
      search: false,
      dataIndex: 'configValue',
    },
    {
      title: '备注',
      search: false,
      dataIndex: 'remark',
    },
    {
      title: '更新时间',
      width: 140,
      search: false,
      dataIndex: 'modifyTime',
    },
    {
      title: '操作',
      search: false,
      fixed: 'right',
      width: 90,
      render: (_, record) => <ModalFormEdit refresh={actionRef.current?.reset} data={record} />,
    },
  ];
  return (
    <ProTable
      {...PROTABLE_DEFAULT_SETTING}
      scroll={{ y: 'calc(100vh - 180px)' }}
      columns={columns}
      request={requestSystemConfig}
      form={{
        colon: false,
      }}
      actionRef={actionRef}
      defaultSize="small"
      rowClassName={(record) => ('expired' in record && record.expired ? 'row-disabled' : '')}
    />
  );
}

export default Config;
