import { useRef } from 'react';
import { DrawerForm, ProFormText } from '@ant-design/pro-form';
import type { ProFormInstance } from '@ant-design/pro-form';
import { Alert, message } from 'antd';
import { googleSMSValidate } from '@/utils/validators';
import { truncateDatabase } from '@/services/monitor';

const formItemLayout = {
  labelCol: {
    style: {
      width: '104px',
    },
  },
};

interface IProps {
  refresh?: any;
  type?: string;
  data?: API.DatabaseItem;
}

function ModalFormBlock({ refresh, data }: IProps) {
  const formRef = useRef<ProFormInstance>();

  const handleFinish = async (values: any) => {
    const res = await truncateDatabase({
      tableName: data?.tableName || '',
      googleCode: values.googleCode,
    });
    if (res.code === '0000') {
      refresh?.();
      formRef.current?.resetFields();
      message.success(`截断成功`);
      return true;
    }
    return false;
  };

  const handleVisibleChange = (visible: boolean) => {
    if (visible) {
      formRef.current?.setFieldsValue({ ...data });
    }
  };

  return (
    <div>
      <DrawerForm
        {...formItemLayout}
        formRef={formRef}
        title="截断数据表"
        layout="horizontal"
        width={520}
        trigger={<a>截断</a>}
        onFinish={handleFinish}
        onVisibleChange={handleVisibleChange}
        initialValues={data}
      >
        <Alert message="截断表有可能导致严重系统故障，非超级管理员请勿操作！！！" type="warning" />
        <br />
        <ProFormText name="tableName" label="表名" readonly required width={500} />
        <ProFormText name="tableComment" label="表备注" readonly required width={500} />
        <ProFormText name="dataLength" label="表大小" readonly required width={500} />
        <ProFormText
          name="googleCode"
          fieldProps={{ maxLength: 6 }}
          label="谷歌验证"
          width={200}
          placeholder="请输入谷歌验证"
          rules={[
            {
              required: true,
              validator: googleSMSValidate,
            },
          ]}
        />
      </DrawerForm>
    </div>
  );
}

export default ModalFormBlock;
