import { history, useModel } from 'umi';
import { authGoogle } from '@/services/admin';
import { isGoogleSms } from '@/utils';
import { Button, Input, message, Result, Space, Steps } from 'antd';
import { useState } from 'react';
import StepOne from './components/StepOne';
import styles from './style.less';

const { Step } = Steps;

function Verify() {
  const [current, setCurrent] = useState<number>(0);
  const [inputValue, setInputValue] = useState<string>('');
  const toPrevious = () => {
    setCurrent((oldCur) => oldCur - 1);
  };
  const { initialState, setInitialState } = useModel('@@initialState');

  const fetchUserInfo = async () => {
    const userInfo = await initialState?.fetchUserInfo?.();
    if (userInfo) {
      await setInitialState((s) => ({
        ...s,
        currentUser: userInfo,
      }));
    }
  };

  const toNext = async () => {
    if (current === 0) {
      setCurrent(1);
    } else if (current === 1) {
      if (!inputValue) {
        message.warn('请先输入Google验证码');
        return;
      }

      if (!isGoogleSms(inputValue)) {
        message.warn('Google验证码为6位数字');
      } else {
        const res = await authGoogle(inputValue);
        if (res.code === '0000') {
          fetchUserInfo();
          setCurrent(2);
        }
      }
    }
  };

  return (
    <div className={styles.container}>
      <Steps current={current}>
        <Step title="第一步：创建秘钥" />
        <Step title="第二步：验证身份" />
        <Step title="第三步：完成设置" />
      </Steps>
      {current === 0 && <StepOne />}
      {current === 1 && (
        <div className={styles.stepTwo}>
          <Input
            value={inputValue}
            maxLength={6}
            onChange={({ target: { value } }) => setInputValue(value)}
            placeholder="在此输入google验证器的验证码，并点击下一步完成绑定"
          />
        </div>
      )}
      {current === 2 && (
        <Result
          status="success"
          title="验证成功!"
          subTitle="恭喜你验证成功"
          extra={[
            <Button type="primary" onClick={() => history.replace('/')}>
              返回首页
            </Button>,
          ]}
        />
      )}
      {current !== 2 && (
        <div className={styles.footer}>
          <Space>
            <Button type="primary" disabled={current === 0} onClick={toPrevious}>
              上一步
            </Button>
            <Button type="primary" onClick={toNext}>
              下一步
            </Button>
          </Space>
        </div>
      )}
    </div>
  );
}

export default Verify;
