import { post, get, commonRequest } from '@/utils/request';
import { message } from 'antd';

const PREFIX = '/api/v1/admin';

/** 获取当前的用户信息 */
export async function currentUser() {
  return get(`${PREFIX}/user/info`);
}

/** 获取当前的商户详情 */
export async function getMerchantDetail() {
  const res = await get(`${PREFIX}/info/detail`);
  if (res.code === '0000') {
    return { ...(res.data || {}), secretKey: '******************' };
  }
  return { secretKey: '******************' };
}

/** 获取商户二次确认码扫码秘钥 */
export async function getGoogleSecret() {
  return get(`${PREFIX}/user/getGoogleSecret`);
}

/** 商户绑定二次确认安全码 */
export async function authGoogle(googleCode: string) {
  return post(`${PREFIX}/user/authGoogle`, { googleCode });
}

/** 获取谷歌秘钥 */
export async function getGoogleApiToken(googleCode: string) {
  return get(`${PREFIX}/config/getApiToken`, { googleCode });
}

/** 重置谷歌秘钥 */
export async function resetGoogleApiToken(googleCode: string) {
  return post(`${PREFIX}/config/resetApiToken`, { googleCode });
}

/** 删除白名单地址 */
export async function deleteIp(whiteIp: string) {
  return post(`${PREFIX}/config/deleteIp`, { whiteIp });
}

/** 添加白名单 */
export async function addIp(whiteIp: string) {
  return post(`${PREFIX}/config/addIp`, { whiteIp });
}

/** 退出登录接口 POST */
export async function outLogin() {
  return get(`${PREFIX}/sso/logout`);
}

/** 登录接口 POST */
export async function login(data: API.LoginParams) {
  return post(`${PREFIX}/sso/login`, data);
}

/** 编辑密码 */
export async function requestResetPwd(data: API.ResetPwdParams) {
  const res = await post(`${PREFIX}/user/resetPwd`, data);
  if (res.code === '0000') {
    message.success('编辑成功');
    return true;
  }
  return false;
}

/** 获取通道列表 */
export async function getProductList() {
  return get(`${PREFIX}/product/list`);
}

/** 银行卡列表 */
export async function requestBankcardList(params: API.PageParams) {
  return commonRequest(`${PREFIX}/card/page`, params);
}

export function getBanks() {
  return get(`${PREFIX}/card/banks`);
}

export function addBankcard(data: API.BankcardItem) {
  return post(`${PREFIX}/card/add`, data);
}

export function deleteBankcard(id: string) {
  return post(`${PREFIX}/card/delete`, { id });
}

/** 流水明细 */
export async function requestSerialList(params: API.PageParams) {
  return commonRequest(`${PREFIX}/bill/page`, params);
}

/** 搜索 */
type ISearchParams = {
  type?: string;
  key?: string;
};
export async function searchQuery(params: ISearchParams) {
  return get(`${PREFIX}/search/query`, params);
}
