import { post, get, commonRequestNoPagination } from '@/utils/request';

const PREFIX = '/api/v1/admin/merchant/transfer/channel';
const PREFIX_PRODUCT = '/api/v1/admin/merchant/transfer/product';

// 合并相同大通道的元素
function handleChannelData(data: API.MerchantChannelItem[]) {
  const dataRep = data;
  const productIdMap = {}; // 每个 id 的 item 在数组中出现的次数统计
  let lastIndex = -1; // 上一个统计结束的元素的 index;
  let lastSymbol = ''; // 上一个统计结束的元素的 symbol;
  let lastBgColor = '';

  dataRep.forEach(({ mchId, productId }, index) => {
    // 唯一标识
    const symbol = `${mchId}${productId}`;

    if (!productIdMap[symbol]) {
      productIdMap[symbol] = 1;

      // 上一类元素第一个元素赋值
      if (lastIndex !== -1) {
        dataRep[lastIndex].productRowSpan = productIdMap[lastSymbol];
        dataRep[lastIndex].bgColor = lastBgColor;
        delete productIdMap[lastSymbol];
      }

      lastBgColor = `bg-color-${(Math.random() * 9 + 1).toFixed(0)}`;
      lastIndex = index;
      lastSymbol = symbol;
    } else {
      // 当前类元素（2-n） 赋值
      productIdMap[symbol] += 1;
      dataRep[index].productRowSpan = 0;
      dataRep[index].bgColor = lastBgColor;
    }
  });

  // 最后一个合并的元素
  dataRep[lastIndex].productRowSpan = productIdMap[lastSymbol];
  dataRep[lastIndex].bgColor = lastBgColor;
  delete productIdMap[lastSymbol];

  return dataRep;
}

/** 支付通道 */
export async function requestPaymentChannelList(params: API.PageParams) {
  const res = await commonRequestNoPagination(`${PREFIX}/list`, params);

  if (res.data.length) {
    res.data = handleChannelData(res.data);
  }
  return res;
}

// 切换状态
export function switchPaymentChannelStatus(id: string, status: number) {
  return post(`${PREFIX}/editStatus`, { id, status });
}

// 编辑权重
export function updatePaymentChannelWeight(id: string, weight: number) {
  return post(`${PREFIX}/editWeight`, { id, weight });
}

// 编辑费率
export function updatePaymentChannelFee(id: string, params: API.MerchantChannelItem) {
  return post(`${PREFIX}/editFee`, { ...params, id });
}

// 编辑日总限额
export function updatePaymentChannelDayLimitAmount(id: string, dayLimitAmount: number) {
  return post(`${PREFIX}/editDayLimitAmount`, { id, dayLimitAmount });
}

// 分流
export function savePaymentChannel(params: API.MerchantChannelItem) {
  return post(`${PREFIX}/save`, params);
}

// 分流配置信息
export function getPaymentChannelConfig(params: {
  mchId: string;
  productId: string;
  channelId: string;
}) {
  return get(`${PREFIX}/detail`, params);
}

// 删除
export function deletePaymentChannel(id: string) {
  return post(`${PREFIX}/delete`, { id });
}

// 编辑费率
export function updatePaymentBatch(params: API.MerchantChannelItem) {
  return post(`${PREFIX_PRODUCT}/edit`, { ...params });
}
