import { post, get, commonRequest } from '@/utils/request';

const PREFIX = '/api/v1/admin/merchant';

/** 商户列表 */
export async function requestMerchantList(params: API.PageParams) {
  return commonRequest(`${PREFIX}/page`, params);
}

export async function getMerchantDetail(id: string) {
  return get(`${PREFIX}/detail`, { id });
}

export function addMerchant(data: API.MerchantItem) {
  return post(`${PREFIX}/add`, data);
}

export function updateMerchant(data: API.MerchantItem) {
  return post(`${PREFIX}/edit`, data);
}

export function editMerchantBasic(data: API.MerchantItem) {
  return post(`${PREFIX}/editBasic`, data);
}

export function editMerchantSafe(data: API.MerchantItem) {
  return post(`${PREFIX}/editSafe`, data);
}

export function clearMerchant(data: any) {
  return post(`${PREFIX}/clear`, data);
}

export function deleteMerchant(id: string) {
  return post(`${PREFIX}/delete`, { id });
}

// 切换商户状态
export function switchMerchantStatus(id: string, status: number) {
  return post(`${PREFIX}/editStatus`, { id, status });
}

// 重置商户密码
export function resetMerchantPwd(id: string) {
  return post(`${PREFIX}/resetPwd`, { id });
}

// 重置商户秘钥
export function resetMerchantToken(id: string) {
  return post(`${PREFIX}/resetApiToken`, { id });
}

// 关闭谷歌验证
export function closeMerchantGoogleAuth(id: string) {
  return post(`${PREFIX}/closeGoogleAuth`, { id });
}

export type ISyncMerchantParams = { srcMchId: number; targetMchIds: number[] };

// 同步商户通道
export function syncMerchant(params: ISyncMerchantParams) {
  return post(`${PREFIX}/sync`, params);
}

/** 商户银行卡列表 */
export async function requestMerchantBankcardList(params: API.PageParams) {
  return commonRequest(`${PREFIX}/card/page`, params);
}

// 新增登录白名单
export function addMerchantLoginIp(params: ISyncMerchantParams) {
  return post(`${PREFIX}/addLoginIp`, params);
}

// 删除登录白名单
export function deleteMerchantLoginIp(id: string) {
  return post(`${PREFIX}/deleteLoginIp`, { id });
}
