import { handleBatchSuccess } from '@/pages/order/payment';
import { commonRequest, get, post } from '@/utils/request';
import { message } from 'antd';

const PREFIX = '/api/v1/admin/transfer';

/** 收单订单记录 */
export async function requestPaymentList(setExtraData: IReactSetState, params: API.PageParams) {
  const res = await commonRequest(`${PREFIX}/order/page`, params);
  if (res.extra) {
    setExtraData(res.extra);
  }
  return res;
}

/** 订单详情 */
export async function getPaymentDetail(serialOrderNo: string) {
  return get(`${PREFIX}/order/detail`, { serialOrderNo });
}

/** 审计订单 */
export async function auditPayment(serialOrderNo: string) {
  return post(`${PREFIX}/order/audit`, { serialOrderNo });
}

/** 批量审计订单 */
export async function auditPaymentBatch(serialOrderNos: (string | number)[]) {
  return post(`${PREFIX}/order/batch/audit`, { serialOrderNos });
}

/** 关闭订单 */
export async function closePayment(serialOrderNo: string) {
  return post(`${PREFIX}/order/close`, { serialOrderNo });
}

/** 批量关闭订单 */
export async function closePaymentBatch(serialOrderNos: (string | number)[]) {
  return post(`${PREFIX}/order/batch/close`, { serialOrderNos });
}

/** 补单 */
export async function replenishmentPayment(refresh: () => void, params: any) {
  const newParams = { ...params };
  const res = await post(`${PREFIX}/order/replenishment`, newParams);
  if (res.code === '0000') {
    await refresh?.();
    message.success('补单成功');
    return true;
  }
  return false;
}

/** 查单 */
export async function queryPayment(serialOrderNo: string) {
  return get(`${PREFIX}/order/channel/query`, { serialOrderNo });
}

/** 批量补单 */
export async function replenishmentPaymentBatch(
  refresh: () => void,
  { serialOrderNos }: any,
  params: any,
) {
  const newParams = { serialOrderNos, ...params };
  const res = await post(`${PREFIX}/order/batch/replenishment`, newParams);
  if (res.code === '0000') {
    await refresh?.();
    handleBatchSuccess('批量补单执行成功', res?.data);
    return true;
  }
  return false;
}

/** 订单通道调用信息 */
export async function getChannelReqLog(serialOrderNo: string) {
  return get(`${PREFIX}/order/channelReqLog`, { serialOrderNo });
}

/** 商户回调状态详情 */
export async function getMerchantNotifyLog(serialOrderNo: string) {
  return get(`${PREFIX}/order/merchantNotifyLog`, { serialOrderNo });
}

/** 重试商户回调 */
export async function retryMerchantNotify(serialOrderNo: string, notifyUrl: string) {
  return post(`${PREFIX}/order/retryNotify`, { serialOrderNo, notifyUrl });
}

/** 批量重试商户回调 */
export async function retryMerchantNotifyBatch(serialOrderNos: (string | number)[]) {
  return post(`${PREFIX}/order/batch/retryNotify`, { serialOrderNos });
}

/** 通道回调状态详情 */
export async function getChannelNotifyLog(serialOrderNo: string) {
  return get(`${PREFIX}/order/channelNotifyLog`, { serialOrderNo });
}

/** 大通道列表 */
export async function requestProductOptions() {
  const res = await get(`${PREFIX}/product/list`);
  if (res.code === '0000') {
    return res.data.map((item: API.PaymentProductItem) => ({
      label: item.productName,
      value: item.id,
    }));
  }
  return [];
}

/** 子通道列表 */
export async function requestChannelOptions() {
  const res = await get(`${PREFIX}/channel/list`);
  if (res.code === '0000') {
    return res.data.map((item: API.PaymentChannelItem) => ({
      label: item.channelName,
      value: item.id,
    }));
  }
  return [];
}
