import { post, commonRequest, get } from '@/utils/request';
import type { IChannelSubItem } from './types';

const PREFIX = '/api/v1/admin/transfer';

/** 大通道 */
export async function requestPaymentProductList(params: API.PageParams) {
  return commonRequest(`${PREFIX}/product/page`, params);
}

export function addPaymentProduct(data: API.PaymentProductItem) {
  return post(`${PREFIX}/product/add`, data);
}

export function updatePaymentProduct(data: API.PaymentProductItem) {
  return post(`${PREFIX}/product/edit`, data);
}

// 复制通道
export function copyPaymentProduct(data: API.PaymentProductItem) {
  return post(`${PREFIX}/product/copy`, data);
}

export function deletePaymentProduct(id: string) {
  return post(`${PREFIX}/product/delete`, { id });
}

// 切换大通道状态
export function switchPaymentProductStatus(id: string, status: number) {
  return post(`${PREFIX}/product/editStatus`, { id, status });
}

/** 子通道 */
export async function requestPaymentChannelList(params: API.PageParams) {
  return commonRequest(`${PREFIX}/channel/page`, params);
}

export function addPaymentChannel(data: API.PaymentChannelItem) {
  return post(`${PREFIX}/channel/add`, data);
}

export function copyPaymentChannel(data: API.PaymentChannelItem) {
  return post(`${PREFIX}/channel/copy`, data);
}

export function updatePaymentChannel(data: API.PaymentProductItem) {
  return post(`${PREFIX}/channel/edit`, data);
}

export function deletePaymentChannel(id: string) {
  return post(`${PREFIX}/channel/delete`, { id });
}

export function switchPaymentChannelStatus(id: string, status: number) {
  return post(`${PREFIX}/channel/editStatus`, { id, status });
}

// 子通道详情
export function getChannelDetail(id: string) {
  return get(`${PREFIX}/channel/detail`, { id });
}

export function editBasic(params: Partial<IChannelSubItem>) {
  return post(`${PREFIX}/channel/editBasic`, params);
}

export function editInvokeParam(params: Partial<IChannelSubItem>) {
  return post(`${PREFIX}/channel/editInvokeParam`, params);
}

export function editFormalParam(params: Partial<IChannelSubItem>) {
  return post(`${PREFIX}/channel/editFormalParam`, params);
}

export function editInvokeResolve(params: Partial<IChannelSubItem>) {
  return post(`${PREFIX}/channel/editInvokeResolve`, params);
}

export function editNotifyResolve(params: Partial<IChannelSubItem>) {
  return post(`${PREFIX}/channel/editNotifyResolve`, params);
}

export function editQueryParam(params: Partial<IChannelSubItem>) {
  return post(`${PREFIX}/channel/editQueryParam`, params);
}
