import { post, commonRequest, commonRequestNoPagination } from '@/utils/request';

const PREFIX = '/api/v1';

/** 系统登录记录 */
export async function requestAdminLog(params: API.PageParams) {
  return commonRequest(`${PREFIX}/admin/login/log/page`, params);
}

/** 商户记录 */
export async function requestMerchantLog(params: API.PageParams) {
  return commonRequest(`${PREFIX}/merchant/login/log/page`, params);
}

/** 黑明单IP */
export async function requestBlackIP(params: API.PageParams) {
  return commonRequest(`${PREFIX}/admin/payment/blackip/page`, params);
}

/** 黑明单IP增 */
export async function addBlackIP(params: API.PageParams) {
  return post(`${PREFIX}/admin/payment/blackip/add`, params);
}

/** 黑明单IP删 */
export async function deleteBlackIP(id: string) {
  return post(`${PREFIX}/admin/payment/blackip/delete`, { id });
}

/** 系统配置 */
export async function requestSystemConfig(params: API.PageParams) {
  return commonRequestNoPagination(`${PREFIX}/system/resource/list`, params);
}

/** 系统配置编辑 */
export async function editSystemConfig(data: API.SystemConfigItem) {
  return post(`${PREFIX}/system/resource/edit`, data);
}

/** 获取缓存 */
export async function requestSystemCache(setCount: (n: number) => void, params: API.PageParams) {
  const res = await commonRequestNoPagination(`${PREFIX}/system/cache/list`, params);
  if (res.data.length) {
    setCount(res.data.length);
  }
  return res;
}

/** 删除缓存 */
export async function deleteSystemCache(key: string) {
  return post(`${PREFIX}/system/cache/delete`, { key });
}
